# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yamcs/protobuf/time/time_service.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yamcs.api import annotations_pb2 as yamcs_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yamcs/protobuf/time/time_service.proto',
  package='yamcs.protobuf.time',
  syntax='proto2',
  serialized_options=b'\n\022org.yamcs.protobufB\020TimeServiceProtoP\001',
  serialized_pb=b'\n&yamcs/protobuf/time/time_service.proto\x12\x13yamcs.protobuf.time\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1byamcs/api/annotations.proto\"\xb1\x01\n\x10LeapSecondsTable\x12\x43\n\x06ranges\x18\x01 \x03(\x0b\x32\x33.yamcs.protobuf.time.LeapSecondsTable.ValidityRange\x1aX\n\rValidityRange\x12\r\n\x05start\x18\x01 \x01(\t\x12\x0c\n\x04stop\x18\x02 \x01(\t\x12\x13\n\x0bleapSeconds\x18\x03 \x01(\x05\x12\x15\n\rtaiDifference\x18\x04 \x01(\x05\"q\n\x0eSetTimeRequest\x12\x10\n\x08instance\x18\x06 \x01(\t\x12)\n\x05time0\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x13\n\x0b\x65lapsedTime\x18\x03 \x01(\x03\x12\r\n\x05speed\x18\x04 \x01(\x01\";\n\x14SubscribeTimeRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x11\n\tprocessor\x18\x02 \x01(\t\";\n\x08TimeInfo\x12/\n\x0b\x63urrentTime\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp2\xd3\x02\n\x07TimeApi\x12h\n\x0eGetLeapSeconds\x12\x16.google.protobuf.Empty\x1a%.yamcs.protobuf.time.LeapSecondsTable\"\x17\x8a\x92\x03\x13\n\x11/api/leap-seconds\x12r\n\x07SetTime\x12#.yamcs.protobuf.time.SetTimeRequest\x1a\x16.google.protobuf.Empty\"*\x8a\x92\x03&\x1a!/api/instances/{instance}:setTime:\x01*\x12\x64\n\rSubscribeTime\x12).yamcs.protobuf.time.SubscribeTimeRequest\x1a\x1a.google.protobuf.Timestamp\"\n\xda\x92\x03\x06\n\x04time0\x01\x1a\x04\xd0\x80\x01\x01\x42(\n\x12org.yamcs.protobufB\x10TimeServiceProtoP\x01'
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,yamcs_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_LEAPSECONDSTABLE_VALIDITYRANGE = _descriptor.Descriptor(
  name='ValidityRange',
  full_name='yamcs.protobuf.time.LeapSecondsTable.ValidityRange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='yamcs.protobuf.time.LeapSecondsTable.ValidityRange.start', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stop', full_name='yamcs.protobuf.time.LeapSecondsTable.ValidityRange.stop', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='leapSeconds', full_name='yamcs.protobuf.time.LeapSecondsTable.ValidityRange.leapSeconds', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='taiDifference', full_name='yamcs.protobuf.time.LeapSecondsTable.ValidityRange.taiDifference', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=244,
  serialized_end=332,
)

_LEAPSECONDSTABLE = _descriptor.Descriptor(
  name='LeapSecondsTable',
  full_name='yamcs.protobuf.time.LeapSecondsTable',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ranges', full_name='yamcs.protobuf.time.LeapSecondsTable.ranges', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_LEAPSECONDSTABLE_VALIDITYRANGE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=155,
  serialized_end=332,
)


_SETTIMEREQUEST = _descriptor.Descriptor(
  name='SetTimeRequest',
  full_name='yamcs.protobuf.time.SetTimeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.time.SetTimeRequest.instance', index=0,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time0', full_name='yamcs.protobuf.time.SetTimeRequest.time0', index=1,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='elapsedTime', full_name='yamcs.protobuf.time.SetTimeRequest.elapsedTime', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='speed', full_name='yamcs.protobuf.time.SetTimeRequest.speed', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=334,
  serialized_end=447,
)


_SUBSCRIBETIMEREQUEST = _descriptor.Descriptor(
  name='SubscribeTimeRequest',
  full_name='yamcs.protobuf.time.SubscribeTimeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.time.SubscribeTimeRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processor', full_name='yamcs.protobuf.time.SubscribeTimeRequest.processor', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=449,
  serialized_end=508,
)


_TIMEINFO = _descriptor.Descriptor(
  name='TimeInfo',
  full_name='yamcs.protobuf.time.TimeInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='currentTime', full_name='yamcs.protobuf.time.TimeInfo.currentTime', index=0,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=510,
  serialized_end=569,
)

_LEAPSECONDSTABLE_VALIDITYRANGE.containing_type = _LEAPSECONDSTABLE
_LEAPSECONDSTABLE.fields_by_name['ranges'].message_type = _LEAPSECONDSTABLE_VALIDITYRANGE
_SETTIMEREQUEST.fields_by_name['time0'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TIMEINFO.fields_by_name['currentTime'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name['LeapSecondsTable'] = _LEAPSECONDSTABLE
DESCRIPTOR.message_types_by_name['SetTimeRequest'] = _SETTIMEREQUEST
DESCRIPTOR.message_types_by_name['SubscribeTimeRequest'] = _SUBSCRIBETIMEREQUEST
DESCRIPTOR.message_types_by_name['TimeInfo'] = _TIMEINFO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LeapSecondsTable = _reflection.GeneratedProtocolMessageType('LeapSecondsTable', (_message.Message,), {

  'ValidityRange' : _reflection.GeneratedProtocolMessageType('ValidityRange', (_message.Message,), {
    'DESCRIPTOR' : _LEAPSECONDSTABLE_VALIDITYRANGE,
    '__module__' : 'yamcs.protobuf.time.time_service_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.time.LeapSecondsTable.ValidityRange)
    })
  ,
  'DESCRIPTOR' : _LEAPSECONDSTABLE,
  '__module__' : 'yamcs.protobuf.time.time_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.time.LeapSecondsTable)
  })
_sym_db.RegisterMessage(LeapSecondsTable)
_sym_db.RegisterMessage(LeapSecondsTable.ValidityRange)

SetTimeRequest = _reflection.GeneratedProtocolMessageType('SetTimeRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETTIMEREQUEST,
  '__module__' : 'yamcs.protobuf.time.time_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.time.SetTimeRequest)
  })
_sym_db.RegisterMessage(SetTimeRequest)

SubscribeTimeRequest = _reflection.GeneratedProtocolMessageType('SubscribeTimeRequest', (_message.Message,), {
  'DESCRIPTOR' : _SUBSCRIBETIMEREQUEST,
  '__module__' : 'yamcs.protobuf.time.time_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.time.SubscribeTimeRequest)
  })
_sym_db.RegisterMessage(SubscribeTimeRequest)

TimeInfo = _reflection.GeneratedProtocolMessageType('TimeInfo', (_message.Message,), {
  'DESCRIPTOR' : _TIMEINFO,
  '__module__' : 'yamcs.protobuf.time.time_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.time.TimeInfo)
  })
_sym_db.RegisterMessage(TimeInfo)


DESCRIPTOR._options = None

_TIMEAPI = _descriptor.ServiceDescriptor(
  name='TimeApi',
  full_name='yamcs.protobuf.time.TimeApi',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\320\200\001\001',
  serialized_start=572,
  serialized_end=911,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetLeapSeconds',
    full_name='yamcs.protobuf.time.TimeApi.GetLeapSeconds',
    index=0,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_LEAPSECONDSTABLE,
    serialized_options=b'\212\222\003\023\n\021/api/leap-seconds',
  ),
  _descriptor.MethodDescriptor(
    name='SetTime',
    full_name='yamcs.protobuf.time.TimeApi.SetTime',
    index=1,
    containing_service=None,
    input_type=_SETTIMEREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\212\222\003&\032!/api/instances/{instance}:setTime:\001*',
  ),
  _descriptor.MethodDescriptor(
    name='SubscribeTime',
    full_name='yamcs.protobuf.time.TimeApi.SubscribeTime',
    index=2,
    containing_service=None,
    input_type=_SUBSCRIBETIMEREQUEST,
    output_type=google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP,
    serialized_options=b'\332\222\003\006\n\004time',
  ),
])
_sym_db.RegisterServiceDescriptor(_TIMEAPI)

DESCRIPTOR.services_by_name['TimeApi'] = _TIMEAPI

# @@protoc_insertion_point(module_scope)
