# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yamcs/protobuf/tco/tco.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yamcs.api import annotations_pb2 as yamcs_dot_api_dot_annotations__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yamcs/protobuf/tco/tco.proto',
  package='yamcs.protobuf.tco',
  syntax='proto2',
  serialized_options=b'\n\022org.yamcs.protobufB\010TcoProtoP\001',
  serialized_pb=b'\n\x1cyamcs/protobuf/tco/tco.proto\x12\x12yamcs.protobuf.tco\x1a\x1byamcs/api/annotations.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"<\n\x13GetTcoConfigRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x13\n\x0bserviceName\x18\x02 \x01(\t\"k\n\x13SetTcoConfigRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x13\n\x0bserviceName\x18\x02 \x01(\t\x12-\n\x06\x63onfig\x18\x03 \x01(\x0b\x32\x1d.yamcs.protobuf.tco.TcoConfig\"8\n\x0fTcoResetRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x13\n\x0bserviceName\x18\x02 \x01(\t\"Y\n\tTcoConfig\x12\x10\n\x08\x61\x63\x63uracy\x18\x01 \x01(\x01\x12\x10\n\x08validity\x18\x02 \x01(\x01\x12\x14\n\x0conboardDelay\x18\x03 \x01(\x01\x12\x12\n\ndefaultTof\x18\x04 \x01(\x01\"<\n\x13GetTcoStatusRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x13\n\x0bserviceName\x18\x02 \x01(\t\"z\n\x16SetCoefficientsRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x13\n\x0bserviceName\x18\x02 \x01(\t\x12\x39\n\x0c\x63oefficients\x18\x03 \x01(\x0b\x32#.yamcs.protobuf.tco.TcoCoefficients\"|\n\x1f\x41\x64\x64TimeOfFlightIntervalsRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x13\n\x0bserviceName\x18\x02 \x01(\t\x12\x32\n\tintervals\x18\x03 \x03(\x0b\x32\x1f.yamcs.protobuf.tco.TofInterval\"\xa0\x01\n\"DeleteTimeOfFlightIntervalsRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x13\n\x0bserviceName\x18\x02 \x01(\t\x12)\n\x05start\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12(\n\x04stop\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"i\n\x0fTcoCoefficients\x12\'\n\x03utc\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0b\n\x03obt\x18\x02 \x01(\x04\x12\x10\n\x08gradient\x18\x03 \x01(\x01\x12\x0e\n\x06offset\x18\x04 \x01(\x01\"\xbf\x01\n\tTcoStatus\x12\x39\n\x0c\x63oefficients\x18\x01 \x01(\x0b\x32#.yamcs.protobuf.tco.TcoCoefficients\x12\x34\n\x10\x63oefficientsTime\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x11\n\tdeviation\x18\x03 \x01(\x01\x12.\n\x07samples\x18\x04 \x03(\x0b\x32\x1d.yamcs.protobuf.tco.TcoSample\"A\n\tTcoSample\x12\'\n\x03utc\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0b\n\x03obt\x18\x02 \x01(\x04\"y\n\x0bTofInterval\x12,\n\x08\x65rtStart\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x07\x65rtStop\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07polCoef\x18\x03 \x03(\x01\x32\x95\x08\n\x12TimeCorrelationApi\x12\x83\x01\n\tGetConfig\x12\'.yamcs.protobuf.tco.GetTcoConfigRequest\x1a\x1d.yamcs.protobuf.tco.TcoConfig\".\x8a\x92\x03*\n(/api/tco/{instance}/{serviceName}/config\x12\x84\x01\n\tSetConfig\x12\'.yamcs.protobuf.tco.SetTcoConfigRequest\x1a\x16.google.protobuf.Empty\"6\x8a\x92\x03\x32\x1a(/api/tco/{instance}/{serviceName}/config:\x06\x63onfig\x12\x83\x01\n\tGetStatus\x12\'.yamcs.protobuf.tco.GetTcoStatusRequest\x1a\x1d.yamcs.protobuf.tco.TcoStatus\".\x8a\x92\x03*\n(/api/tco/{instance}/{serviceName}/status\x12\x99\x01\n\x0fSetCoefficients\x12*.yamcs.protobuf.tco.SetCoefficientsRequest\x1a\x16.google.protobuf.Empty\"B\x8a\x92\x03>\x1a./api/tco/{instance}/{serviceName}/coefficients:\x0c\x63oefficients\x12s\n\x05Reset\x12#.yamcs.protobuf.tco.TcoResetRequest\x1a\x16.google.protobuf.Empty\"-\x8a\x92\x03)\x1a\'/api/tco/{instance}/{serviceName}:reset\x12\xa4\x01\n\x18\x41\x64\x64TimeOfFlightIntervals\x12\x33.yamcs.protobuf.tco.AddTimeOfFlightIntervalsRequest\x1a\x16.google.protobuf.Empty\";\x8a\x92\x03\x37\x1a\x32/api/tco/{instance}/{serviceName}/tof:addIntervals:\x01*\x12\xad\x01\n\x1b\x44\x65leteTimeOfFlightIntervals\x12\x36.yamcs.protobuf.tco.DeleteTimeOfFlightIntervalsRequest\x1a\x16.google.protobuf.Empty\">\x8a\x92\x03:\x1a\x35/api/tco/{instance}/{serviceName}/tof:deleteIntervals:\x01*\x1a\x04\xd0\x80\x01\x01\x42 \n\x12org.yamcs.protobufB\x08TcoProtoP\x01'
  ,
  dependencies=[yamcs_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])




_GETTCOCONFIGREQUEST = _descriptor.Descriptor(
  name='GetTcoConfigRequest',
  full_name='yamcs.protobuf.tco.GetTcoConfigRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.tco.GetTcoConfigRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='serviceName', full_name='yamcs.protobuf.tco.GetTcoConfigRequest.serviceName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=143,
  serialized_end=203,
)


_SETTCOCONFIGREQUEST = _descriptor.Descriptor(
  name='SetTcoConfigRequest',
  full_name='yamcs.protobuf.tco.SetTcoConfigRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.tco.SetTcoConfigRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='serviceName', full_name='yamcs.protobuf.tco.SetTcoConfigRequest.serviceName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='config', full_name='yamcs.protobuf.tco.SetTcoConfigRequest.config', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=205,
  serialized_end=312,
)


_TCORESETREQUEST = _descriptor.Descriptor(
  name='TcoResetRequest',
  full_name='yamcs.protobuf.tco.TcoResetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.tco.TcoResetRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='serviceName', full_name='yamcs.protobuf.tco.TcoResetRequest.serviceName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=314,
  serialized_end=370,
)


_TCOCONFIG = _descriptor.Descriptor(
  name='TcoConfig',
  full_name='yamcs.protobuf.tco.TcoConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='accuracy', full_name='yamcs.protobuf.tco.TcoConfig.accuracy', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='validity', full_name='yamcs.protobuf.tco.TcoConfig.validity', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='onboardDelay', full_name='yamcs.protobuf.tco.TcoConfig.onboardDelay', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='defaultTof', full_name='yamcs.protobuf.tco.TcoConfig.defaultTof', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=372,
  serialized_end=461,
)


_GETTCOSTATUSREQUEST = _descriptor.Descriptor(
  name='GetTcoStatusRequest',
  full_name='yamcs.protobuf.tco.GetTcoStatusRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.tco.GetTcoStatusRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='serviceName', full_name='yamcs.protobuf.tco.GetTcoStatusRequest.serviceName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=463,
  serialized_end=523,
)


_SETCOEFFICIENTSREQUEST = _descriptor.Descriptor(
  name='SetCoefficientsRequest',
  full_name='yamcs.protobuf.tco.SetCoefficientsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.tco.SetCoefficientsRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='serviceName', full_name='yamcs.protobuf.tco.SetCoefficientsRequest.serviceName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='coefficients', full_name='yamcs.protobuf.tco.SetCoefficientsRequest.coefficients', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=525,
  serialized_end=647,
)


_ADDTIMEOFFLIGHTINTERVALSREQUEST = _descriptor.Descriptor(
  name='AddTimeOfFlightIntervalsRequest',
  full_name='yamcs.protobuf.tco.AddTimeOfFlightIntervalsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.tco.AddTimeOfFlightIntervalsRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='serviceName', full_name='yamcs.protobuf.tco.AddTimeOfFlightIntervalsRequest.serviceName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='intervals', full_name='yamcs.protobuf.tco.AddTimeOfFlightIntervalsRequest.intervals', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=649,
  serialized_end=773,
)


_DELETETIMEOFFLIGHTINTERVALSREQUEST = _descriptor.Descriptor(
  name='DeleteTimeOfFlightIntervalsRequest',
  full_name='yamcs.protobuf.tco.DeleteTimeOfFlightIntervalsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.tco.DeleteTimeOfFlightIntervalsRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='serviceName', full_name='yamcs.protobuf.tco.DeleteTimeOfFlightIntervalsRequest.serviceName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start', full_name='yamcs.protobuf.tco.DeleteTimeOfFlightIntervalsRequest.start', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stop', full_name='yamcs.protobuf.tco.DeleteTimeOfFlightIntervalsRequest.stop', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=776,
  serialized_end=936,
)


_TCOCOEFFICIENTS = _descriptor.Descriptor(
  name='TcoCoefficients',
  full_name='yamcs.protobuf.tco.TcoCoefficients',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='utc', full_name='yamcs.protobuf.tco.TcoCoefficients.utc', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='obt', full_name='yamcs.protobuf.tco.TcoCoefficients.obt', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gradient', full_name='yamcs.protobuf.tco.TcoCoefficients.gradient', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='offset', full_name='yamcs.protobuf.tco.TcoCoefficients.offset', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=938,
  serialized_end=1043,
)


_TCOSTATUS = _descriptor.Descriptor(
  name='TcoStatus',
  full_name='yamcs.protobuf.tco.TcoStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='coefficients', full_name='yamcs.protobuf.tco.TcoStatus.coefficients', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='coefficientsTime', full_name='yamcs.protobuf.tco.TcoStatus.coefficientsTime', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deviation', full_name='yamcs.protobuf.tco.TcoStatus.deviation', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='samples', full_name='yamcs.protobuf.tco.TcoStatus.samples', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1046,
  serialized_end=1237,
)


_TCOSAMPLE = _descriptor.Descriptor(
  name='TcoSample',
  full_name='yamcs.protobuf.tco.TcoSample',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='utc', full_name='yamcs.protobuf.tco.TcoSample.utc', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='obt', full_name='yamcs.protobuf.tco.TcoSample.obt', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1239,
  serialized_end=1304,
)


_TOFINTERVAL = _descriptor.Descriptor(
  name='TofInterval',
  full_name='yamcs.protobuf.tco.TofInterval',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ertStart', full_name='yamcs.protobuf.tco.TofInterval.ertStart', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ertStop', full_name='yamcs.protobuf.tco.TofInterval.ertStop', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='polCoef', full_name='yamcs.protobuf.tco.TofInterval.polCoef', index=2,
      number=3, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1306,
  serialized_end=1427,
)

_SETTCOCONFIGREQUEST.fields_by_name['config'].message_type = _TCOCONFIG
_SETCOEFFICIENTSREQUEST.fields_by_name['coefficients'].message_type = _TCOCOEFFICIENTS
_ADDTIMEOFFLIGHTINTERVALSREQUEST.fields_by_name['intervals'].message_type = _TOFINTERVAL
_DELETETIMEOFFLIGHTINTERVALSREQUEST.fields_by_name['start'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_DELETETIMEOFFLIGHTINTERVALSREQUEST.fields_by_name['stop'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TCOCOEFFICIENTS.fields_by_name['utc'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TCOSTATUS.fields_by_name['coefficients'].message_type = _TCOCOEFFICIENTS
_TCOSTATUS.fields_by_name['coefficientsTime'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TCOSTATUS.fields_by_name['samples'].message_type = _TCOSAMPLE
_TCOSAMPLE.fields_by_name['utc'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TOFINTERVAL.fields_by_name['ertStart'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TOFINTERVAL.fields_by_name['ertStop'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name['GetTcoConfigRequest'] = _GETTCOCONFIGREQUEST
DESCRIPTOR.message_types_by_name['SetTcoConfigRequest'] = _SETTCOCONFIGREQUEST
DESCRIPTOR.message_types_by_name['TcoResetRequest'] = _TCORESETREQUEST
DESCRIPTOR.message_types_by_name['TcoConfig'] = _TCOCONFIG
DESCRIPTOR.message_types_by_name['GetTcoStatusRequest'] = _GETTCOSTATUSREQUEST
DESCRIPTOR.message_types_by_name['SetCoefficientsRequest'] = _SETCOEFFICIENTSREQUEST
DESCRIPTOR.message_types_by_name['AddTimeOfFlightIntervalsRequest'] = _ADDTIMEOFFLIGHTINTERVALSREQUEST
DESCRIPTOR.message_types_by_name['DeleteTimeOfFlightIntervalsRequest'] = _DELETETIMEOFFLIGHTINTERVALSREQUEST
DESCRIPTOR.message_types_by_name['TcoCoefficients'] = _TCOCOEFFICIENTS
DESCRIPTOR.message_types_by_name['TcoStatus'] = _TCOSTATUS
DESCRIPTOR.message_types_by_name['TcoSample'] = _TCOSAMPLE
DESCRIPTOR.message_types_by_name['TofInterval'] = _TOFINTERVAL
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetTcoConfigRequest = _reflection.GeneratedProtocolMessageType('GetTcoConfigRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETTCOCONFIGREQUEST,
  '__module__' : 'yamcs.protobuf.tco.tco_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.tco.GetTcoConfigRequest)
  })
_sym_db.RegisterMessage(GetTcoConfigRequest)

SetTcoConfigRequest = _reflection.GeneratedProtocolMessageType('SetTcoConfigRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETTCOCONFIGREQUEST,
  '__module__' : 'yamcs.protobuf.tco.tco_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.tco.SetTcoConfigRequest)
  })
_sym_db.RegisterMessage(SetTcoConfigRequest)

TcoResetRequest = _reflection.GeneratedProtocolMessageType('TcoResetRequest', (_message.Message,), {
  'DESCRIPTOR' : _TCORESETREQUEST,
  '__module__' : 'yamcs.protobuf.tco.tco_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.tco.TcoResetRequest)
  })
_sym_db.RegisterMessage(TcoResetRequest)

TcoConfig = _reflection.GeneratedProtocolMessageType('TcoConfig', (_message.Message,), {
  'DESCRIPTOR' : _TCOCONFIG,
  '__module__' : 'yamcs.protobuf.tco.tco_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.tco.TcoConfig)
  })
_sym_db.RegisterMessage(TcoConfig)

GetTcoStatusRequest = _reflection.GeneratedProtocolMessageType('GetTcoStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETTCOSTATUSREQUEST,
  '__module__' : 'yamcs.protobuf.tco.tco_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.tco.GetTcoStatusRequest)
  })
_sym_db.RegisterMessage(GetTcoStatusRequest)

SetCoefficientsRequest = _reflection.GeneratedProtocolMessageType('SetCoefficientsRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETCOEFFICIENTSREQUEST,
  '__module__' : 'yamcs.protobuf.tco.tco_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.tco.SetCoefficientsRequest)
  })
_sym_db.RegisterMessage(SetCoefficientsRequest)

AddTimeOfFlightIntervalsRequest = _reflection.GeneratedProtocolMessageType('AddTimeOfFlightIntervalsRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADDTIMEOFFLIGHTINTERVALSREQUEST,
  '__module__' : 'yamcs.protobuf.tco.tco_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.tco.AddTimeOfFlightIntervalsRequest)
  })
_sym_db.RegisterMessage(AddTimeOfFlightIntervalsRequest)

DeleteTimeOfFlightIntervalsRequest = _reflection.GeneratedProtocolMessageType('DeleteTimeOfFlightIntervalsRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETETIMEOFFLIGHTINTERVALSREQUEST,
  '__module__' : 'yamcs.protobuf.tco.tco_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.tco.DeleteTimeOfFlightIntervalsRequest)
  })
_sym_db.RegisterMessage(DeleteTimeOfFlightIntervalsRequest)

TcoCoefficients = _reflection.GeneratedProtocolMessageType('TcoCoefficients', (_message.Message,), {
  'DESCRIPTOR' : _TCOCOEFFICIENTS,
  '__module__' : 'yamcs.protobuf.tco.tco_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.tco.TcoCoefficients)
  })
_sym_db.RegisterMessage(TcoCoefficients)

TcoStatus = _reflection.GeneratedProtocolMessageType('TcoStatus', (_message.Message,), {
  'DESCRIPTOR' : _TCOSTATUS,
  '__module__' : 'yamcs.protobuf.tco.tco_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.tco.TcoStatus)
  })
_sym_db.RegisterMessage(TcoStatus)

TcoSample = _reflection.GeneratedProtocolMessageType('TcoSample', (_message.Message,), {
  'DESCRIPTOR' : _TCOSAMPLE,
  '__module__' : 'yamcs.protobuf.tco.tco_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.tco.TcoSample)
  })
_sym_db.RegisterMessage(TcoSample)

TofInterval = _reflection.GeneratedProtocolMessageType('TofInterval', (_message.Message,), {
  'DESCRIPTOR' : _TOFINTERVAL,
  '__module__' : 'yamcs.protobuf.tco.tco_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.tco.TofInterval)
  })
_sym_db.RegisterMessage(TofInterval)


DESCRIPTOR._options = None

_TIMECORRELATIONAPI = _descriptor.ServiceDescriptor(
  name='TimeCorrelationApi',
  full_name='yamcs.protobuf.tco.TimeCorrelationApi',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\320\200\001\001',
  serialized_start=1430,
  serialized_end=2475,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetConfig',
    full_name='yamcs.protobuf.tco.TimeCorrelationApi.GetConfig',
    index=0,
    containing_service=None,
    input_type=_GETTCOCONFIGREQUEST,
    output_type=_TCOCONFIG,
    serialized_options=b'\212\222\003*\n(/api/tco/{instance}/{serviceName}/config',
  ),
  _descriptor.MethodDescriptor(
    name='SetConfig',
    full_name='yamcs.protobuf.tco.TimeCorrelationApi.SetConfig',
    index=1,
    containing_service=None,
    input_type=_SETTCOCONFIGREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\212\222\0032\032(/api/tco/{instance}/{serviceName}/config:\006config',
  ),
  _descriptor.MethodDescriptor(
    name='GetStatus',
    full_name='yamcs.protobuf.tco.TimeCorrelationApi.GetStatus',
    index=2,
    containing_service=None,
    input_type=_GETTCOSTATUSREQUEST,
    output_type=_TCOSTATUS,
    serialized_options=b'\212\222\003*\n(/api/tco/{instance}/{serviceName}/status',
  ),
  _descriptor.MethodDescriptor(
    name='SetCoefficients',
    full_name='yamcs.protobuf.tco.TimeCorrelationApi.SetCoefficients',
    index=3,
    containing_service=None,
    input_type=_SETCOEFFICIENTSREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\212\222\003>\032./api/tco/{instance}/{serviceName}/coefficients:\014coefficients',
  ),
  _descriptor.MethodDescriptor(
    name='Reset',
    full_name='yamcs.protobuf.tco.TimeCorrelationApi.Reset',
    index=4,
    containing_service=None,
    input_type=_TCORESETREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\212\222\003)\032\'/api/tco/{instance}/{serviceName}:reset',
  ),
  _descriptor.MethodDescriptor(
    name='AddTimeOfFlightIntervals',
    full_name='yamcs.protobuf.tco.TimeCorrelationApi.AddTimeOfFlightIntervals',
    index=5,
    containing_service=None,
    input_type=_ADDTIMEOFFLIGHTINTERVALSREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\212\222\0037\0322/api/tco/{instance}/{serviceName}/tof:addIntervals:\001*',
  ),
  _descriptor.MethodDescriptor(
    name='DeleteTimeOfFlightIntervals',
    full_name='yamcs.protobuf.tco.TimeCorrelationApi.DeleteTimeOfFlightIntervals',
    index=6,
    containing_service=None,
    input_type=_DELETETIMEOFFLIGHTINTERVALSREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\212\222\003:\0325/api/tco/{instance}/{serviceName}/tof:deleteIntervals:\001*',
  ),
])
_sym_db.RegisterServiceDescriptor(_TIMECORRELATIONAPI)

DESCRIPTOR.services_by_name['TimeCorrelationApi'] = _TIMECORRELATIONAPI

# @@protoc_insertion_point(module_scope)
