# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yamcs/protobuf/instances/instances_service.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from yamcs.api import annotations_pb2 as yamcs_dot_api_dot_annotations__pb2
from yamcs.protobuf.instances import instances_pb2 as yamcs_dot_protobuf_dot_instances_dot_instances__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yamcs/protobuf/instances/instances_service.proto',
  package='yamcs.protobuf.instances',
  syntax='proto2',
  serialized_options=b'\n\022org.yamcs.protobufB\025InstancesServiceProtoP\001',
  serialized_pb=b'\n0yamcs/protobuf/instances/instances_service.proto\x12\x18yamcs.protobuf.instances\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1byamcs/api/annotations.proto\x1a(yamcs/protobuf/instances/instances.proto\"&\n\x14ListInstancesRequest\x12\x0e\n\x06\x66ilter\x18\x01 \x03(\t\"S\n\x15ListInstancesResponse\x12:\n\tinstances\x18\x01 \x03(\x0b\x32\'.yamcs.protobuf.instances.YamcsInstance\"\xc1\x02\n\x15\x43reateInstanceRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08template\x18\x02 \x01(\t\x12W\n\x0ctemplateArgs\x18\x03 \x03(\x0b\x32\x41.yamcs.protobuf.instances.CreateInstanceRequest.TemplateArgsEntry\x12K\n\x06labels\x18\x04 \x03(\x0b\x32;.yamcs.protobuf.instances.CreateInstanceRequest.LabelsEntry\x1a\x33\n\x11TemplateArgsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xc2\x02\n\x1aReconfigureInstanceRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\\\n\x0ctemplateArgs\x18\x02 \x03(\x0b\x32\x46.yamcs.protobuf.instances.ReconfigureInstanceRequest.TemplateArgsEntry\x12P\n\x06labels\x18\x03 \x03(\x0b\x32@.yamcs.protobuf.instances.ReconfigureInstanceRequest.LabelsEntry\x1a\x33\n\x11TemplateArgsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"^\n\x1dListInstanceTemplatesResponse\x12=\n\ttemplates\x18\x01 \x03(\x0b\x32*.yamcs.protobuf.instances.InstanceTemplate\".\n\x1aGetInstanceTemplateRequest\x12\x10\n\x08template\x18\x01 \x01(\t\"&\n\x12GetInstanceRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\"(\n\x14StartInstanceRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\"\'\n\x13StopInstanceRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\"*\n\x16RestartInstanceRequest\x12\x10\n\x08instance\x18\x01 \x01(\t2\xa3\x0b\n\x0cInstancesApi\x12\x87\x01\n\x15ListInstanceTemplates\x12\x16.google.protobuf.Empty\x1a\x37.yamcs.protobuf.instances.ListInstanceTemplatesResponse\"\x1d\x8a\x92\x03\x19\n\x17/api/instance-templates\x12\xa1\x01\n\x13GetInstanceTemplate\x12\x34.yamcs.protobuf.instances.GetInstanceTemplateRequest\x1a*.yamcs.protobuf.instances.InstanceTemplate\"(\x8a\x92\x03$\n\"/api/instance-templates/{template}\x12\x86\x01\n\rListInstances\x12..yamcs.protobuf.instances.ListInstancesRequest\x1a/.yamcs.protobuf.instances.ListInstancesResponse\"\x14\x8a\x92\x03\x10\n\x0e/api/instances\x12h\n\x12SubscribeInstances\x12\x16.google.protobuf.Empty\x1a\'.yamcs.protobuf.instances.YamcsInstance\"\x0f\xda\x92\x03\x0b\n\tinstances0\x01\x12\x85\x01\n\x0bGetInstance\x12,.yamcs.protobuf.instances.GetInstanceRequest\x1a\'.yamcs.protobuf.instances.YamcsInstance\"\x1f\x8a\x92\x03\x1b\n\x19/api/instances/{instance}\x12\x83\x01\n\x0e\x43reateInstance\x12/.yamcs.protobuf.instances.CreateInstanceRequest\x1a\'.yamcs.protobuf.instances.YamcsInstance\"\x17\x8a\x92\x03\x13\x1a\x0e/api/instances:\x01*\x12\xa4\x01\n\x13ReconfigureInstance\x12\x34.yamcs.protobuf.instances.ReconfigureInstanceRequest\x1a\'.yamcs.protobuf.instances.YamcsInstance\".\x8a\x92\x03*\x1a%/api/instances/{instance}:reconfigure:\x01*\x12\x8f\x01\n\rStartInstance\x12..yamcs.protobuf.instances.StartInstanceRequest\x1a\'.yamcs.protobuf.instances.YamcsInstance\"%\x8a\x92\x03!\x1a\x1f/api/instances/{instance}:start\x12\x8c\x01\n\x0cStopInstance\x12-.yamcs.protobuf.instances.StopInstanceRequest\x1a\'.yamcs.protobuf.instances.YamcsInstance\"$\x8a\x92\x03 \x1a\x1e/api/instances/{instance}:stop\x12\x95\x01\n\x0fRestartInstance\x12\x30.yamcs.protobuf.instances.RestartInstanceRequest\x1a\'.yamcs.protobuf.instances.YamcsInstance\"\'\x8a\x92\x03#\x1a!/api/instances/{instance}:restart\x1a\x04\xd0\x80\x01\x01\x42-\n\x12org.yamcs.protobufB\x15InstancesServiceProtoP\x01'
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,yamcs_dot_api_dot_annotations__pb2.DESCRIPTOR,yamcs_dot_protobuf_dot_instances_dot_instances__pb2.DESCRIPTOR,])




_LISTINSTANCESREQUEST = _descriptor.Descriptor(
  name='ListInstancesRequest',
  full_name='yamcs.protobuf.instances.ListInstancesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='filter', full_name='yamcs.protobuf.instances.ListInstancesRequest.filter', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=178,
  serialized_end=216,
)


_LISTINSTANCESRESPONSE = _descriptor.Descriptor(
  name='ListInstancesResponse',
  full_name='yamcs.protobuf.instances.ListInstancesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instances', full_name='yamcs.protobuf.instances.ListInstancesResponse.instances', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=218,
  serialized_end=301,
)


_CREATEINSTANCEREQUEST_TEMPLATEARGSENTRY = _descriptor.Descriptor(
  name='TemplateArgsEntry',
  full_name='yamcs.protobuf.instances.CreateInstanceRequest.TemplateArgsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yamcs.protobuf.instances.CreateInstanceRequest.TemplateArgsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='yamcs.protobuf.instances.CreateInstanceRequest.TemplateArgsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=527,
  serialized_end=578,
)

_CREATEINSTANCEREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yamcs.protobuf.instances.CreateInstanceRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yamcs.protobuf.instances.CreateInstanceRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='yamcs.protobuf.instances.CreateInstanceRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=580,
  serialized_end=625,
)

_CREATEINSTANCEREQUEST = _descriptor.Descriptor(
  name='CreateInstanceRequest',
  full_name='yamcs.protobuf.instances.CreateInstanceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.instances.CreateInstanceRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='template', full_name='yamcs.protobuf.instances.CreateInstanceRequest.template', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='templateArgs', full_name='yamcs.protobuf.instances.CreateInstanceRequest.templateArgs', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yamcs.protobuf.instances.CreateInstanceRequest.labels', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CREATEINSTANCEREQUEST_TEMPLATEARGSENTRY, _CREATEINSTANCEREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=304,
  serialized_end=625,
)


_RECONFIGUREINSTANCEREQUEST_TEMPLATEARGSENTRY = _descriptor.Descriptor(
  name='TemplateArgsEntry',
  full_name='yamcs.protobuf.instances.ReconfigureInstanceRequest.TemplateArgsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yamcs.protobuf.instances.ReconfigureInstanceRequest.TemplateArgsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='yamcs.protobuf.instances.ReconfigureInstanceRequest.TemplateArgsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=527,
  serialized_end=578,
)

_RECONFIGUREINSTANCEREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yamcs.protobuf.instances.ReconfigureInstanceRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yamcs.protobuf.instances.ReconfigureInstanceRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='yamcs.protobuf.instances.ReconfigureInstanceRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=580,
  serialized_end=625,
)

_RECONFIGUREINSTANCEREQUEST = _descriptor.Descriptor(
  name='ReconfigureInstanceRequest',
  full_name='yamcs.protobuf.instances.ReconfigureInstanceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.instances.ReconfigureInstanceRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='templateArgs', full_name='yamcs.protobuf.instances.ReconfigureInstanceRequest.templateArgs', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yamcs.protobuf.instances.ReconfigureInstanceRequest.labels', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_RECONFIGUREINSTANCEREQUEST_TEMPLATEARGSENTRY, _RECONFIGUREINSTANCEREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=628,
  serialized_end=950,
)


_LISTINSTANCETEMPLATESRESPONSE = _descriptor.Descriptor(
  name='ListInstanceTemplatesResponse',
  full_name='yamcs.protobuf.instances.ListInstanceTemplatesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='templates', full_name='yamcs.protobuf.instances.ListInstanceTemplatesResponse.templates', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=952,
  serialized_end=1046,
)


_GETINSTANCETEMPLATEREQUEST = _descriptor.Descriptor(
  name='GetInstanceTemplateRequest',
  full_name='yamcs.protobuf.instances.GetInstanceTemplateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='template', full_name='yamcs.protobuf.instances.GetInstanceTemplateRequest.template', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1048,
  serialized_end=1094,
)


_GETINSTANCEREQUEST = _descriptor.Descriptor(
  name='GetInstanceRequest',
  full_name='yamcs.protobuf.instances.GetInstanceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.instances.GetInstanceRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1096,
  serialized_end=1134,
)


_STARTINSTANCEREQUEST = _descriptor.Descriptor(
  name='StartInstanceRequest',
  full_name='yamcs.protobuf.instances.StartInstanceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.instances.StartInstanceRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1136,
  serialized_end=1176,
)


_STOPINSTANCEREQUEST = _descriptor.Descriptor(
  name='StopInstanceRequest',
  full_name='yamcs.protobuf.instances.StopInstanceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.instances.StopInstanceRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1178,
  serialized_end=1217,
)


_RESTARTINSTANCEREQUEST = _descriptor.Descriptor(
  name='RestartInstanceRequest',
  full_name='yamcs.protobuf.instances.RestartInstanceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.instances.RestartInstanceRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1219,
  serialized_end=1261,
)

_LISTINSTANCESRESPONSE.fields_by_name['instances'].message_type = yamcs_dot_protobuf_dot_instances_dot_instances__pb2._YAMCSINSTANCE
_CREATEINSTANCEREQUEST_TEMPLATEARGSENTRY.containing_type = _CREATEINSTANCEREQUEST
_CREATEINSTANCEREQUEST_LABELSENTRY.containing_type = _CREATEINSTANCEREQUEST
_CREATEINSTANCEREQUEST.fields_by_name['templateArgs'].message_type = _CREATEINSTANCEREQUEST_TEMPLATEARGSENTRY
_CREATEINSTANCEREQUEST.fields_by_name['labels'].message_type = _CREATEINSTANCEREQUEST_LABELSENTRY
_RECONFIGUREINSTANCEREQUEST_TEMPLATEARGSENTRY.containing_type = _RECONFIGUREINSTANCEREQUEST
_RECONFIGUREINSTANCEREQUEST_LABELSENTRY.containing_type = _RECONFIGUREINSTANCEREQUEST
_RECONFIGUREINSTANCEREQUEST.fields_by_name['templateArgs'].message_type = _RECONFIGUREINSTANCEREQUEST_TEMPLATEARGSENTRY
_RECONFIGUREINSTANCEREQUEST.fields_by_name['labels'].message_type = _RECONFIGUREINSTANCEREQUEST_LABELSENTRY
_LISTINSTANCETEMPLATESRESPONSE.fields_by_name['templates'].message_type = yamcs_dot_protobuf_dot_instances_dot_instances__pb2._INSTANCETEMPLATE
DESCRIPTOR.message_types_by_name['ListInstancesRequest'] = _LISTINSTANCESREQUEST
DESCRIPTOR.message_types_by_name['ListInstancesResponse'] = _LISTINSTANCESRESPONSE
DESCRIPTOR.message_types_by_name['CreateInstanceRequest'] = _CREATEINSTANCEREQUEST
DESCRIPTOR.message_types_by_name['ReconfigureInstanceRequest'] = _RECONFIGUREINSTANCEREQUEST
DESCRIPTOR.message_types_by_name['ListInstanceTemplatesResponse'] = _LISTINSTANCETEMPLATESRESPONSE
DESCRIPTOR.message_types_by_name['GetInstanceTemplateRequest'] = _GETINSTANCETEMPLATEREQUEST
DESCRIPTOR.message_types_by_name['GetInstanceRequest'] = _GETINSTANCEREQUEST
DESCRIPTOR.message_types_by_name['StartInstanceRequest'] = _STARTINSTANCEREQUEST
DESCRIPTOR.message_types_by_name['StopInstanceRequest'] = _STOPINSTANCEREQUEST
DESCRIPTOR.message_types_by_name['RestartInstanceRequest'] = _RESTARTINSTANCEREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListInstancesRequest = _reflection.GeneratedProtocolMessageType('ListInstancesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTINSTANCESREQUEST,
  '__module__' : 'yamcs.protobuf.instances.instances_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.instances.ListInstancesRequest)
  })
_sym_db.RegisterMessage(ListInstancesRequest)

ListInstancesResponse = _reflection.GeneratedProtocolMessageType('ListInstancesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTINSTANCESRESPONSE,
  '__module__' : 'yamcs.protobuf.instances.instances_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.instances.ListInstancesResponse)
  })
_sym_db.RegisterMessage(ListInstancesResponse)

CreateInstanceRequest = _reflection.GeneratedProtocolMessageType('CreateInstanceRequest', (_message.Message,), {

  'TemplateArgsEntry' : _reflection.GeneratedProtocolMessageType('TemplateArgsEntry', (_message.Message,), {
    'DESCRIPTOR' : _CREATEINSTANCEREQUEST_TEMPLATEARGSENTRY,
    '__module__' : 'yamcs.protobuf.instances.instances_service_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.instances.CreateInstanceRequest.TemplateArgsEntry)
    })
  ,

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _CREATEINSTANCEREQUEST_LABELSENTRY,
    '__module__' : 'yamcs.protobuf.instances.instances_service_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.instances.CreateInstanceRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _CREATEINSTANCEREQUEST,
  '__module__' : 'yamcs.protobuf.instances.instances_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.instances.CreateInstanceRequest)
  })
_sym_db.RegisterMessage(CreateInstanceRequest)
_sym_db.RegisterMessage(CreateInstanceRequest.TemplateArgsEntry)
_sym_db.RegisterMessage(CreateInstanceRequest.LabelsEntry)

ReconfigureInstanceRequest = _reflection.GeneratedProtocolMessageType('ReconfigureInstanceRequest', (_message.Message,), {

  'TemplateArgsEntry' : _reflection.GeneratedProtocolMessageType('TemplateArgsEntry', (_message.Message,), {
    'DESCRIPTOR' : _RECONFIGUREINSTANCEREQUEST_TEMPLATEARGSENTRY,
    '__module__' : 'yamcs.protobuf.instances.instances_service_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.instances.ReconfigureInstanceRequest.TemplateArgsEntry)
    })
  ,

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _RECONFIGUREINSTANCEREQUEST_LABELSENTRY,
    '__module__' : 'yamcs.protobuf.instances.instances_service_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.instances.ReconfigureInstanceRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _RECONFIGUREINSTANCEREQUEST,
  '__module__' : 'yamcs.protobuf.instances.instances_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.instances.ReconfigureInstanceRequest)
  })
_sym_db.RegisterMessage(ReconfigureInstanceRequest)
_sym_db.RegisterMessage(ReconfigureInstanceRequest.TemplateArgsEntry)
_sym_db.RegisterMessage(ReconfigureInstanceRequest.LabelsEntry)

ListInstanceTemplatesResponse = _reflection.GeneratedProtocolMessageType('ListInstanceTemplatesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTINSTANCETEMPLATESRESPONSE,
  '__module__' : 'yamcs.protobuf.instances.instances_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.instances.ListInstanceTemplatesResponse)
  })
_sym_db.RegisterMessage(ListInstanceTemplatesResponse)

GetInstanceTemplateRequest = _reflection.GeneratedProtocolMessageType('GetInstanceTemplateRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETINSTANCETEMPLATEREQUEST,
  '__module__' : 'yamcs.protobuf.instances.instances_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.instances.GetInstanceTemplateRequest)
  })
_sym_db.RegisterMessage(GetInstanceTemplateRequest)

GetInstanceRequest = _reflection.GeneratedProtocolMessageType('GetInstanceRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETINSTANCEREQUEST,
  '__module__' : 'yamcs.protobuf.instances.instances_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.instances.GetInstanceRequest)
  })
_sym_db.RegisterMessage(GetInstanceRequest)

StartInstanceRequest = _reflection.GeneratedProtocolMessageType('StartInstanceRequest', (_message.Message,), {
  'DESCRIPTOR' : _STARTINSTANCEREQUEST,
  '__module__' : 'yamcs.protobuf.instances.instances_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.instances.StartInstanceRequest)
  })
_sym_db.RegisterMessage(StartInstanceRequest)

StopInstanceRequest = _reflection.GeneratedProtocolMessageType('StopInstanceRequest', (_message.Message,), {
  'DESCRIPTOR' : _STOPINSTANCEREQUEST,
  '__module__' : 'yamcs.protobuf.instances.instances_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.instances.StopInstanceRequest)
  })
_sym_db.RegisterMessage(StopInstanceRequest)

RestartInstanceRequest = _reflection.GeneratedProtocolMessageType('RestartInstanceRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESTARTINSTANCEREQUEST,
  '__module__' : 'yamcs.protobuf.instances.instances_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.instances.RestartInstanceRequest)
  })
_sym_db.RegisterMessage(RestartInstanceRequest)


DESCRIPTOR._options = None
_CREATEINSTANCEREQUEST_TEMPLATEARGSENTRY._options = None
_CREATEINSTANCEREQUEST_LABELSENTRY._options = None
_RECONFIGUREINSTANCEREQUEST_TEMPLATEARGSENTRY._options = None
_RECONFIGUREINSTANCEREQUEST_LABELSENTRY._options = None

_INSTANCESAPI = _descriptor.ServiceDescriptor(
  name='InstancesApi',
  full_name='yamcs.protobuf.instances.InstancesApi',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\320\200\001\001',
  serialized_start=1264,
  serialized_end=2707,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListInstanceTemplates',
    full_name='yamcs.protobuf.instances.InstancesApi.ListInstanceTemplates',
    index=0,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_LISTINSTANCETEMPLATESRESPONSE,
    serialized_options=b'\212\222\003\031\n\027/api/instance-templates',
  ),
  _descriptor.MethodDescriptor(
    name='GetInstanceTemplate',
    full_name='yamcs.protobuf.instances.InstancesApi.GetInstanceTemplate',
    index=1,
    containing_service=None,
    input_type=_GETINSTANCETEMPLATEREQUEST,
    output_type=yamcs_dot_protobuf_dot_instances_dot_instances__pb2._INSTANCETEMPLATE,
    serialized_options=b'\212\222\003$\n\"/api/instance-templates/{template}',
  ),
  _descriptor.MethodDescriptor(
    name='ListInstances',
    full_name='yamcs.protobuf.instances.InstancesApi.ListInstances',
    index=2,
    containing_service=None,
    input_type=_LISTINSTANCESREQUEST,
    output_type=_LISTINSTANCESRESPONSE,
    serialized_options=b'\212\222\003\020\n\016/api/instances',
  ),
  _descriptor.MethodDescriptor(
    name='SubscribeInstances',
    full_name='yamcs.protobuf.instances.InstancesApi.SubscribeInstances',
    index=3,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=yamcs_dot_protobuf_dot_instances_dot_instances__pb2._YAMCSINSTANCE,
    serialized_options=b'\332\222\003\013\n\tinstances',
  ),
  _descriptor.MethodDescriptor(
    name='GetInstance',
    full_name='yamcs.protobuf.instances.InstancesApi.GetInstance',
    index=4,
    containing_service=None,
    input_type=_GETINSTANCEREQUEST,
    output_type=yamcs_dot_protobuf_dot_instances_dot_instances__pb2._YAMCSINSTANCE,
    serialized_options=b'\212\222\003\033\n\031/api/instances/{instance}',
  ),
  _descriptor.MethodDescriptor(
    name='CreateInstance',
    full_name='yamcs.protobuf.instances.InstancesApi.CreateInstance',
    index=5,
    containing_service=None,
    input_type=_CREATEINSTANCEREQUEST,
    output_type=yamcs_dot_protobuf_dot_instances_dot_instances__pb2._YAMCSINSTANCE,
    serialized_options=b'\212\222\003\023\032\016/api/instances:\001*',
  ),
  _descriptor.MethodDescriptor(
    name='ReconfigureInstance',
    full_name='yamcs.protobuf.instances.InstancesApi.ReconfigureInstance',
    index=6,
    containing_service=None,
    input_type=_RECONFIGUREINSTANCEREQUEST,
    output_type=yamcs_dot_protobuf_dot_instances_dot_instances__pb2._YAMCSINSTANCE,
    serialized_options=b'\212\222\003*\032%/api/instances/{instance}:reconfigure:\001*',
  ),
  _descriptor.MethodDescriptor(
    name='StartInstance',
    full_name='yamcs.protobuf.instances.InstancesApi.StartInstance',
    index=7,
    containing_service=None,
    input_type=_STARTINSTANCEREQUEST,
    output_type=yamcs_dot_protobuf_dot_instances_dot_instances__pb2._YAMCSINSTANCE,
    serialized_options=b'\212\222\003!\032\037/api/instances/{instance}:start',
  ),
  _descriptor.MethodDescriptor(
    name='StopInstance',
    full_name='yamcs.protobuf.instances.InstancesApi.StopInstance',
    index=8,
    containing_service=None,
    input_type=_STOPINSTANCEREQUEST,
    output_type=yamcs_dot_protobuf_dot_instances_dot_instances__pb2._YAMCSINSTANCE,
    serialized_options=b'\212\222\003 \032\036/api/instances/{instance}:stop',
  ),
  _descriptor.MethodDescriptor(
    name='RestartInstance',
    full_name='yamcs.protobuf.instances.InstancesApi.RestartInstance',
    index=9,
    containing_service=None,
    input_type=_RESTARTINSTANCEREQUEST,
    output_type=yamcs_dot_protobuf_dot_instances_dot_instances__pb2._YAMCSINSTANCE,
    serialized_options=b'\212\222\003#\032!/api/instances/{instance}:restart',
  ),
])
_sym_db.RegisterServiceDescriptor(_INSTANCESAPI)

DESCRIPTOR.services_by_name['InstancesApi'] = _INSTANCESAPI

# @@protoc_insertion_point(module_scope)
