# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yamcs/protobuf/plists/plists_service.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from yamcs.api import annotations_pb2 as yamcs_dot_api_dot_annotations__pb2
from yamcs.protobuf.plists import plists_pb2 as yamcs_dot_protobuf_dot_plists_dot_plists__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yamcs/protobuf/plists/plists_service.proto',
  package='yamcs.protobuf.plists',
  syntax='proto2',
  serialized_options=b'\n\031org.yamcs.protobuf.plistsB\032ParameterListsServiceProtoP\001',
  serialized_pb=b'\n*yamcs/protobuf/plists/plists_service.proto\x12\x15yamcs.protobuf.plists\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1byamcs/api/annotations.proto\x1a\"yamcs/protobuf/plists/plists.proto\"-\n\x19ListParameterListsRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\"9\n\x17GetParameterListRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x0c\n\x04list\x18\x02 \x01(\t\"U\n\x1aListParameterListsResponse\x12\x37\n\x05lists\x18\x01 \x03(\x0b\x32(.yamcs.protobuf.plists.ParameterListInfo\"c\n\x1a\x43reateParameterListRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x10\n\x08patterns\x18\x04 \x03(\t\"\xa4\x01\n\x1aUpdateParameterListRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x0c\n\x04list\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x43\n\x11patternDefinition\x18\x05 \x01(\x0b\x32(.yamcs.protobuf.plists.PatternDefinition\"%\n\x11PatternDefinition\x12\x10\n\x08patterns\x18\x01 \x03(\t\"<\n\x1a\x44\x65leteParameterListRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x0c\n\x04list\x18\x02 \x01(\t2\xcd\x06\n\x11ParameterListsApi\x12\xa6\x01\n\x12ListParameterLists\x12\x30.yamcs.protobuf.plists.ListParameterListsRequest\x1a\x31.yamcs.protobuf.plists.ListParameterListsResponse\"+\x8a\x92\x03\'\n%/api/parameter-lists/{instance}/lists\x12\xa0\x01\n\x10GetParameterList\x12..yamcs.protobuf.plists.GetParameterListRequest\x1a(.yamcs.protobuf.plists.ParameterListInfo\"2\x8a\x92\x03.\n,/api/parameter-lists/{instance}/lists/{list}\x12\xa2\x01\n\x13\x43reateParameterList\x12\x31.yamcs.protobuf.plists.CreateParameterListRequest\x1a(.yamcs.protobuf.plists.ParameterListInfo\".\x8a\x92\x03*\x1a%/api/parameter-lists/{instance}/lists:\x01*\x12\xa9\x01\n\x13UpdateParameterList\x12\x31.yamcs.protobuf.plists.UpdateParameterListRequest\x1a(.yamcs.protobuf.plists.ParameterListInfo\"5\x8a\x92\x03\x31*,/api/parameter-lists/{instance}/lists/{list}:\x01*\x12\x94\x01\n\x13\x44\x65leteParameterList\x12\x31.yamcs.protobuf.plists.DeleteParameterListRequest\x1a\x16.google.protobuf.Empty\"2\x8a\x92\x03.\",/api/parameter-lists/{instance}/lists/{list}\x1a\x04\xd0\x80\x01\x01\x42\x39\n\x19org.yamcs.protobuf.plistsB\x1aParameterListsServiceProtoP\x01'
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,yamcs_dot_api_dot_annotations__pb2.DESCRIPTOR,yamcs_dot_protobuf_dot_plists_dot_plists__pb2.DESCRIPTOR,])




_LISTPARAMETERLISTSREQUEST = _descriptor.Descriptor(
  name='ListParameterListsRequest',
  full_name='yamcs.protobuf.plists.ListParameterListsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.plists.ListParameterListsRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=163,
  serialized_end=208,
)


_GETPARAMETERLISTREQUEST = _descriptor.Descriptor(
  name='GetParameterListRequest',
  full_name='yamcs.protobuf.plists.GetParameterListRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.plists.GetParameterListRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='list', full_name='yamcs.protobuf.plists.GetParameterListRequest.list', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=210,
  serialized_end=267,
)


_LISTPARAMETERLISTSRESPONSE = _descriptor.Descriptor(
  name='ListParameterListsResponse',
  full_name='yamcs.protobuf.plists.ListParameterListsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='lists', full_name='yamcs.protobuf.plists.ListParameterListsResponse.lists', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=269,
  serialized_end=354,
)


_CREATEPARAMETERLISTREQUEST = _descriptor.Descriptor(
  name='CreateParameterListRequest',
  full_name='yamcs.protobuf.plists.CreateParameterListRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.plists.CreateParameterListRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.plists.CreateParameterListRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='yamcs.protobuf.plists.CreateParameterListRequest.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='patterns', full_name='yamcs.protobuf.plists.CreateParameterListRequest.patterns', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=356,
  serialized_end=455,
)


_UPDATEPARAMETERLISTREQUEST = _descriptor.Descriptor(
  name='UpdateParameterListRequest',
  full_name='yamcs.protobuf.plists.UpdateParameterListRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.plists.UpdateParameterListRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='list', full_name='yamcs.protobuf.plists.UpdateParameterListRequest.list', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.plists.UpdateParameterListRequest.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='yamcs.protobuf.plists.UpdateParameterListRequest.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='patternDefinition', full_name='yamcs.protobuf.plists.UpdateParameterListRequest.patternDefinition', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=458,
  serialized_end=622,
)


_PATTERNDEFINITION = _descriptor.Descriptor(
  name='PatternDefinition',
  full_name='yamcs.protobuf.plists.PatternDefinition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='patterns', full_name='yamcs.protobuf.plists.PatternDefinition.patterns', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=624,
  serialized_end=661,
)


_DELETEPARAMETERLISTREQUEST = _descriptor.Descriptor(
  name='DeleteParameterListRequest',
  full_name='yamcs.protobuf.plists.DeleteParameterListRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.plists.DeleteParameterListRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='list', full_name='yamcs.protobuf.plists.DeleteParameterListRequest.list', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=663,
  serialized_end=723,
)

_LISTPARAMETERLISTSRESPONSE.fields_by_name['lists'].message_type = yamcs_dot_protobuf_dot_plists_dot_plists__pb2._PARAMETERLISTINFO
_UPDATEPARAMETERLISTREQUEST.fields_by_name['patternDefinition'].message_type = _PATTERNDEFINITION
DESCRIPTOR.message_types_by_name['ListParameterListsRequest'] = _LISTPARAMETERLISTSREQUEST
DESCRIPTOR.message_types_by_name['GetParameterListRequest'] = _GETPARAMETERLISTREQUEST
DESCRIPTOR.message_types_by_name['ListParameterListsResponse'] = _LISTPARAMETERLISTSRESPONSE
DESCRIPTOR.message_types_by_name['CreateParameterListRequest'] = _CREATEPARAMETERLISTREQUEST
DESCRIPTOR.message_types_by_name['UpdateParameterListRequest'] = _UPDATEPARAMETERLISTREQUEST
DESCRIPTOR.message_types_by_name['PatternDefinition'] = _PATTERNDEFINITION
DESCRIPTOR.message_types_by_name['DeleteParameterListRequest'] = _DELETEPARAMETERLISTREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListParameterListsRequest = _reflection.GeneratedProtocolMessageType('ListParameterListsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTPARAMETERLISTSREQUEST,
  '__module__' : 'yamcs.protobuf.plists.plists_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.plists.ListParameterListsRequest)
  })
_sym_db.RegisterMessage(ListParameterListsRequest)

GetParameterListRequest = _reflection.GeneratedProtocolMessageType('GetParameterListRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPARAMETERLISTREQUEST,
  '__module__' : 'yamcs.protobuf.plists.plists_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.plists.GetParameterListRequest)
  })
_sym_db.RegisterMessage(GetParameterListRequest)

ListParameterListsResponse = _reflection.GeneratedProtocolMessageType('ListParameterListsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTPARAMETERLISTSRESPONSE,
  '__module__' : 'yamcs.protobuf.plists.plists_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.plists.ListParameterListsResponse)
  })
_sym_db.RegisterMessage(ListParameterListsResponse)

CreateParameterListRequest = _reflection.GeneratedProtocolMessageType('CreateParameterListRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPARAMETERLISTREQUEST,
  '__module__' : 'yamcs.protobuf.plists.plists_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.plists.CreateParameterListRequest)
  })
_sym_db.RegisterMessage(CreateParameterListRequest)

UpdateParameterListRequest = _reflection.GeneratedProtocolMessageType('UpdateParameterListRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPARAMETERLISTREQUEST,
  '__module__' : 'yamcs.protobuf.plists.plists_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.plists.UpdateParameterListRequest)
  })
_sym_db.RegisterMessage(UpdateParameterListRequest)

PatternDefinition = _reflection.GeneratedProtocolMessageType('PatternDefinition', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNDEFINITION,
  '__module__' : 'yamcs.protobuf.plists.plists_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.plists.PatternDefinition)
  })
_sym_db.RegisterMessage(PatternDefinition)

DeleteParameterListRequest = _reflection.GeneratedProtocolMessageType('DeleteParameterListRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEPARAMETERLISTREQUEST,
  '__module__' : 'yamcs.protobuf.plists.plists_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.plists.DeleteParameterListRequest)
  })
_sym_db.RegisterMessage(DeleteParameterListRequest)


DESCRIPTOR._options = None

_PARAMETERLISTSAPI = _descriptor.ServiceDescriptor(
  name='ParameterListsApi',
  full_name='yamcs.protobuf.plists.ParameterListsApi',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\320\200\001\001',
  serialized_start=726,
  serialized_end=1571,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListParameterLists',
    full_name='yamcs.protobuf.plists.ParameterListsApi.ListParameterLists',
    index=0,
    containing_service=None,
    input_type=_LISTPARAMETERLISTSREQUEST,
    output_type=_LISTPARAMETERLISTSRESPONSE,
    serialized_options=b'\212\222\003\'\n%/api/parameter-lists/{instance}/lists',
  ),
  _descriptor.MethodDescriptor(
    name='GetParameterList',
    full_name='yamcs.protobuf.plists.ParameterListsApi.GetParameterList',
    index=1,
    containing_service=None,
    input_type=_GETPARAMETERLISTREQUEST,
    output_type=yamcs_dot_protobuf_dot_plists_dot_plists__pb2._PARAMETERLISTINFO,
    serialized_options=b'\212\222\003.\n,/api/parameter-lists/{instance}/lists/{list}',
  ),
  _descriptor.MethodDescriptor(
    name='CreateParameterList',
    full_name='yamcs.protobuf.plists.ParameterListsApi.CreateParameterList',
    index=2,
    containing_service=None,
    input_type=_CREATEPARAMETERLISTREQUEST,
    output_type=yamcs_dot_protobuf_dot_plists_dot_plists__pb2._PARAMETERLISTINFO,
    serialized_options=b'\212\222\003*\032%/api/parameter-lists/{instance}/lists:\001*',
  ),
  _descriptor.MethodDescriptor(
    name='UpdateParameterList',
    full_name='yamcs.protobuf.plists.ParameterListsApi.UpdateParameterList',
    index=3,
    containing_service=None,
    input_type=_UPDATEPARAMETERLISTREQUEST,
    output_type=yamcs_dot_protobuf_dot_plists_dot_plists__pb2._PARAMETERLISTINFO,
    serialized_options=b'\212\222\0031*,/api/parameter-lists/{instance}/lists/{list}:\001*',
  ),
  _descriptor.MethodDescriptor(
    name='DeleteParameterList',
    full_name='yamcs.protobuf.plists.ParameterListsApi.DeleteParameterList',
    index=4,
    containing_service=None,
    input_type=_DELETEPARAMETERLISTREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\212\222\003.\",/api/parameter-lists/{instance}/lists/{list}',
  ),
])
_sym_db.RegisterServiceDescriptor(_PARAMETERLISTSAPI)

DESCRIPTOR.services_by_name['ParameterListsApi'] = _PARAMETERLISTSAPI

# @@protoc_insertion_point(module_scope)
