# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yamcs/protobuf/archive/parameter_archive_service.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yamcs.api import annotations_pb2 as yamcs_dot_api_dot_annotations__pb2
from yamcs.protobuf import yamcs_pb2 as yamcs_dot_protobuf_dot_yamcs__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yamcs/protobuf/archive/parameter_archive_service.proto',
  package='yamcs.protobuf.archive',
  syntax='proto2',
  serialized_options=b'\n\022org.yamcs.protobufB\034ParameterArchiveServiceProtoP\001',
  serialized_pb=b'\n6yamcs/protobuf/archive/parameter_archive_service.proto\x12\x16yamcs.protobuf.archive\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1byamcs/api/annotations.proto\x1a\x1ayamcs/protobuf/yamcs.proto\"/\n\x1bSubscribeBackfillingRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\"\xfe\x01\n\x18SubscribeBackfillingData\x12W\n\x08\x66inished\x18\x01 \x03(\x0b\x32\x45.yamcs.protobuf.archive.SubscribeBackfillingData.BackfillFinishedInfo\x1a\x88\x01\n\x14\x42\x61\x63kfillFinishedInfo\x12)\n\x05start\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12(\n\x04stop\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1b\n\x13processedParameters\x18\x03 \x01(\x04\"|\n\x13RebuildRangeRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12)\n\x05start\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12(\n\x04stop\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\" \n\x0cPurgeRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\"a\n GetArchivedParametersInfoRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x0e\n\x06\x66ilter\x18\x04 \x01(\t\x12\r\n\x05limit\x18\x07 \x01(\x05\x12\x0c\n\x04next\x18\x08 \x01(\t\"\x99\x01\n#GetArchivedParameterSegmentsRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x0b\n\x03pid\x18\x02 \x01(\r\x12)\n\x05start\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12(\n\x04stop\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x9f\x01\n\x15\x41rchivedParameterInfo\x12\x0b\n\x03pid\x18\x01 \x01(\r\x12\x11\n\tparameter\x18\x02 \x01(\t\x12+\n\x07rawType\x18\x03 \x01(\x0e\x32\x1a.yamcs.protobuf.Value.Type\x12+\n\x07\x65ngType\x18\x04 \x01(\x0e\x32\x1a.yamcs.protobuf.Value.Type\x12\x0c\n\x04gids\x18\x05 \x03(\r\"x\n\x1e\x41rchivedParametersInfoResponse\x12;\n\x04pids\x18\x01 \x03(\x0b\x32-.yamcs.protobuf.archive.ArchivedParameterInfo\x12\x19\n\x11\x63ontinuationToken\x18\x02 \x01(\t\"\x91\x01\n\x1b\x41rchiveParameterSegmentInfo\x12\x0f\n\x07groupId\x18\x01 \x01(\r\x12)\n\x05start\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\'\n\x03\x65nd\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05\x63ount\x18\x04 \x01(\r\"\xb0\x01\n!ArchivedParameterSegmentsResponse\x12\x44\n\rparameterInfo\x18\x01 \x01(\x0b\x32-.yamcs.protobuf.archive.ArchivedParameterInfo\x12\x45\n\x08segments\x18\x02 \x03(\x0b\x32\x33.yamcs.protobuf.archive.ArchiveParameterSegmentInfo\"A\n GetArchivedParameterGroupRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x0b\n\x03gid\x18\x02 \x01(\r\"p\n\x1e\x41rchivedParameterGroupResponse\x12\x0b\n\x03gid\x18\x01 \x01(\r\x12\x41\n\nparameters\x18\x02 \x03(\x0b\x32-.yamcs.protobuf.archive.ArchivedParameterInfo\",\n\x18\x45nableBackfillingRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\"-\n\x19\x44isableBackfillingRequest\x12\x10\n\x08instance\x18\x01 \x01(\t2\xa8\x0c\n\x13ParameterArchiveApi\x12\x90\x01\n\x0cRebuildRange\x12+.yamcs.protobuf.archive.RebuildRangeRequest\x1a\x16.google.protobuf.Empty\";\x8a\x92\x03\x37\x1a\x30/api/archive/{instance}/parameterArchive:rebuild:\x01*H\x01\x12\xf9\x01\n\x19GetArchivedParametersInfo\x12\x38.yamcs.protobuf.archive.GetArchivedParametersInfoRequest\x1a\x36.yamcs.protobuf.archive.ArchivedParametersInfoResponse\"j\x8a\x92\x03\x66\n&/api/parameter-archive/{instance}/pidsZ<\n8/api/archive/{instance}/parameterArchive/info/parameters0\x01\x12\x95\x02\n\x1cGetArchivedParameterSegments\x12;.yamcs.protobuf.archive.GetArchivedParameterSegmentsRequest\x1a\x39.yamcs.protobuf.archive.ArchivedParameterSegmentsResponse\"}\x8a\x92\x03y\n5/api/parameter-archive/{instance}/pids/{pid}/segmentsZ@\n</api/archive/{instance}/parameterArchive/info/segments/{pid}0\x01\x12\x81\x02\n\x19GetArchivedParameterGroup\x12\x38.yamcs.protobuf.archive.GetArchivedParameterGroupRequest\x1a\x36.yamcs.protobuf.archive.ArchivedParameterGroupResponse\"r\x8a\x92\x03n\n,/api/parameter-archive/{instance}/gids/{gid}Z>\n:/api/archive/{instance}/parameterArchive/info/groups/{gid}0\x01\x12~\n\x05Purge\x12$.yamcs.protobuf.archive.PurgeRequest\x1a\x16.google.protobuf.Empty\"7\x8a\x92\x03\x33\x1a./api/archive/{instance}/parameterArchive:purge:\x01*\x12\xa5\x01\n\x12\x44isableBackfilling\x12\x31.yamcs.protobuf.archive.DisableBackfillingRequest\x1a\x16.google.protobuf.Empty\"D\x8a\x92\x03@\x1a;/api/archive/{instance}/parameterArchive:disableBackfilling:\x01*\x12\xa2\x01\n\x11\x45nableBackfilling\x12\x30.yamcs.protobuf.archive.EnableBackfillingRequest\x1a\x16.google.protobuf.Empty\"C\x8a\x92\x03?\x1a:/api/archive/{instance}/parameterArchive:enableBackfilling:\x01*\x12\x92\x01\n\x14SubscribeBackfilling\x12\x33.yamcs.protobuf.archive.SubscribeBackfillingRequest\x1a\x30.yamcs.protobuf.archive.SubscribeBackfillingData\"\x11\xda\x92\x03\r\n\x0b\x62\x61\x63kfilling0\x01\x1a\x04\xd0\x80\x01\x01\x42\x34\n\x12org.yamcs.protobufB\x1cParameterArchiveServiceProtoP\x01'
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,yamcs_dot_api_dot_annotations__pb2.DESCRIPTOR,yamcs_dot_protobuf_dot_yamcs__pb2.DESCRIPTOR,])




_SUBSCRIBEBACKFILLINGREQUEST = _descriptor.Descriptor(
  name='SubscribeBackfillingRequest',
  full_name='yamcs.protobuf.archive.SubscribeBackfillingRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.archive.SubscribeBackfillingRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=201,
  serialized_end=248,
)


_SUBSCRIBEBACKFILLINGDATA_BACKFILLFINISHEDINFO = _descriptor.Descriptor(
  name='BackfillFinishedInfo',
  full_name='yamcs.protobuf.archive.SubscribeBackfillingData.BackfillFinishedInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='yamcs.protobuf.archive.SubscribeBackfillingData.BackfillFinishedInfo.start', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stop', full_name='yamcs.protobuf.archive.SubscribeBackfillingData.BackfillFinishedInfo.stop', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processedParameters', full_name='yamcs.protobuf.archive.SubscribeBackfillingData.BackfillFinishedInfo.processedParameters', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=369,
  serialized_end=505,
)

_SUBSCRIBEBACKFILLINGDATA = _descriptor.Descriptor(
  name='SubscribeBackfillingData',
  full_name='yamcs.protobuf.archive.SubscribeBackfillingData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='finished', full_name='yamcs.protobuf.archive.SubscribeBackfillingData.finished', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_SUBSCRIBEBACKFILLINGDATA_BACKFILLFINISHEDINFO, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=251,
  serialized_end=505,
)


_REBUILDRANGEREQUEST = _descriptor.Descriptor(
  name='RebuildRangeRequest',
  full_name='yamcs.protobuf.archive.RebuildRangeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.archive.RebuildRangeRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start', full_name='yamcs.protobuf.archive.RebuildRangeRequest.start', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stop', full_name='yamcs.protobuf.archive.RebuildRangeRequest.stop', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=507,
  serialized_end=631,
)


_PURGEREQUEST = _descriptor.Descriptor(
  name='PurgeRequest',
  full_name='yamcs.protobuf.archive.PurgeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.archive.PurgeRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=633,
  serialized_end=665,
)


_GETARCHIVEDPARAMETERSINFOREQUEST = _descriptor.Descriptor(
  name='GetArchivedParametersInfoRequest',
  full_name='yamcs.protobuf.archive.GetArchivedParametersInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.archive.GetArchivedParametersInfoRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='filter', full_name='yamcs.protobuf.archive.GetArchivedParametersInfoRequest.filter', index=1,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='limit', full_name='yamcs.protobuf.archive.GetArchivedParametersInfoRequest.limit', index=2,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='next', full_name='yamcs.protobuf.archive.GetArchivedParametersInfoRequest.next', index=3,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=667,
  serialized_end=764,
)


_GETARCHIVEDPARAMETERSEGMENTSREQUEST = _descriptor.Descriptor(
  name='GetArchivedParameterSegmentsRequest',
  full_name='yamcs.protobuf.archive.GetArchivedParameterSegmentsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.archive.GetArchivedParameterSegmentsRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pid', full_name='yamcs.protobuf.archive.GetArchivedParameterSegmentsRequest.pid', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start', full_name='yamcs.protobuf.archive.GetArchivedParameterSegmentsRequest.start', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stop', full_name='yamcs.protobuf.archive.GetArchivedParameterSegmentsRequest.stop', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=767,
  serialized_end=920,
)


_ARCHIVEDPARAMETERINFO = _descriptor.Descriptor(
  name='ArchivedParameterInfo',
  full_name='yamcs.protobuf.archive.ArchivedParameterInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pid', full_name='yamcs.protobuf.archive.ArchivedParameterInfo.pid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parameter', full_name='yamcs.protobuf.archive.ArchivedParameterInfo.parameter', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rawType', full_name='yamcs.protobuf.archive.ArchivedParameterInfo.rawType', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='engType', full_name='yamcs.protobuf.archive.ArchivedParameterInfo.engType', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gids', full_name='yamcs.protobuf.archive.ArchivedParameterInfo.gids', index=4,
      number=5, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=923,
  serialized_end=1082,
)


_ARCHIVEDPARAMETERSINFORESPONSE = _descriptor.Descriptor(
  name='ArchivedParametersInfoResponse',
  full_name='yamcs.protobuf.archive.ArchivedParametersInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pids', full_name='yamcs.protobuf.archive.ArchivedParametersInfoResponse.pids', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='continuationToken', full_name='yamcs.protobuf.archive.ArchivedParametersInfoResponse.continuationToken', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1084,
  serialized_end=1204,
)


_ARCHIVEPARAMETERSEGMENTINFO = _descriptor.Descriptor(
  name='ArchiveParameterSegmentInfo',
  full_name='yamcs.protobuf.archive.ArchiveParameterSegmentInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='groupId', full_name='yamcs.protobuf.archive.ArchiveParameterSegmentInfo.groupId', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start', full_name='yamcs.protobuf.archive.ArchiveParameterSegmentInfo.start', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end', full_name='yamcs.protobuf.archive.ArchiveParameterSegmentInfo.end', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='count', full_name='yamcs.protobuf.archive.ArchiveParameterSegmentInfo.count', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1207,
  serialized_end=1352,
)


_ARCHIVEDPARAMETERSEGMENTSRESPONSE = _descriptor.Descriptor(
  name='ArchivedParameterSegmentsResponse',
  full_name='yamcs.protobuf.archive.ArchivedParameterSegmentsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='parameterInfo', full_name='yamcs.protobuf.archive.ArchivedParameterSegmentsResponse.parameterInfo', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='segments', full_name='yamcs.protobuf.archive.ArchivedParameterSegmentsResponse.segments', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1355,
  serialized_end=1531,
)


_GETARCHIVEDPARAMETERGROUPREQUEST = _descriptor.Descriptor(
  name='GetArchivedParameterGroupRequest',
  full_name='yamcs.protobuf.archive.GetArchivedParameterGroupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.archive.GetArchivedParameterGroupRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gid', full_name='yamcs.protobuf.archive.GetArchivedParameterGroupRequest.gid', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1533,
  serialized_end=1598,
)


_ARCHIVEDPARAMETERGROUPRESPONSE = _descriptor.Descriptor(
  name='ArchivedParameterGroupResponse',
  full_name='yamcs.protobuf.archive.ArchivedParameterGroupResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gid', full_name='yamcs.protobuf.archive.ArchivedParameterGroupResponse.gid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parameters', full_name='yamcs.protobuf.archive.ArchivedParameterGroupResponse.parameters', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1600,
  serialized_end=1712,
)


_ENABLEBACKFILLINGREQUEST = _descriptor.Descriptor(
  name='EnableBackfillingRequest',
  full_name='yamcs.protobuf.archive.EnableBackfillingRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.archive.EnableBackfillingRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1714,
  serialized_end=1758,
)


_DISABLEBACKFILLINGREQUEST = _descriptor.Descriptor(
  name='DisableBackfillingRequest',
  full_name='yamcs.protobuf.archive.DisableBackfillingRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.archive.DisableBackfillingRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1760,
  serialized_end=1805,
)

_SUBSCRIBEBACKFILLINGDATA_BACKFILLFINISHEDINFO.fields_by_name['start'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SUBSCRIBEBACKFILLINGDATA_BACKFILLFINISHEDINFO.fields_by_name['stop'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SUBSCRIBEBACKFILLINGDATA_BACKFILLFINISHEDINFO.containing_type = _SUBSCRIBEBACKFILLINGDATA
_SUBSCRIBEBACKFILLINGDATA.fields_by_name['finished'].message_type = _SUBSCRIBEBACKFILLINGDATA_BACKFILLFINISHEDINFO
_REBUILDRANGEREQUEST.fields_by_name['start'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_REBUILDRANGEREQUEST.fields_by_name['stop'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_GETARCHIVEDPARAMETERSEGMENTSREQUEST.fields_by_name['start'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_GETARCHIVEDPARAMETERSEGMENTSREQUEST.fields_by_name['stop'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ARCHIVEDPARAMETERINFO.fields_by_name['rawType'].enum_type = yamcs_dot_protobuf_dot_yamcs__pb2._VALUE_TYPE
_ARCHIVEDPARAMETERINFO.fields_by_name['engType'].enum_type = yamcs_dot_protobuf_dot_yamcs__pb2._VALUE_TYPE
_ARCHIVEDPARAMETERSINFORESPONSE.fields_by_name['pids'].message_type = _ARCHIVEDPARAMETERINFO
_ARCHIVEPARAMETERSEGMENTINFO.fields_by_name['start'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ARCHIVEPARAMETERSEGMENTINFO.fields_by_name['end'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ARCHIVEDPARAMETERSEGMENTSRESPONSE.fields_by_name['parameterInfo'].message_type = _ARCHIVEDPARAMETERINFO
_ARCHIVEDPARAMETERSEGMENTSRESPONSE.fields_by_name['segments'].message_type = _ARCHIVEPARAMETERSEGMENTINFO
_ARCHIVEDPARAMETERGROUPRESPONSE.fields_by_name['parameters'].message_type = _ARCHIVEDPARAMETERINFO
DESCRIPTOR.message_types_by_name['SubscribeBackfillingRequest'] = _SUBSCRIBEBACKFILLINGREQUEST
DESCRIPTOR.message_types_by_name['SubscribeBackfillingData'] = _SUBSCRIBEBACKFILLINGDATA
DESCRIPTOR.message_types_by_name['RebuildRangeRequest'] = _REBUILDRANGEREQUEST
DESCRIPTOR.message_types_by_name['PurgeRequest'] = _PURGEREQUEST
DESCRIPTOR.message_types_by_name['GetArchivedParametersInfoRequest'] = _GETARCHIVEDPARAMETERSINFOREQUEST
DESCRIPTOR.message_types_by_name['GetArchivedParameterSegmentsRequest'] = _GETARCHIVEDPARAMETERSEGMENTSREQUEST
DESCRIPTOR.message_types_by_name['ArchivedParameterInfo'] = _ARCHIVEDPARAMETERINFO
DESCRIPTOR.message_types_by_name['ArchivedParametersInfoResponse'] = _ARCHIVEDPARAMETERSINFORESPONSE
DESCRIPTOR.message_types_by_name['ArchiveParameterSegmentInfo'] = _ARCHIVEPARAMETERSEGMENTINFO
DESCRIPTOR.message_types_by_name['ArchivedParameterSegmentsResponse'] = _ARCHIVEDPARAMETERSEGMENTSRESPONSE
DESCRIPTOR.message_types_by_name['GetArchivedParameterGroupRequest'] = _GETARCHIVEDPARAMETERGROUPREQUEST
DESCRIPTOR.message_types_by_name['ArchivedParameterGroupResponse'] = _ARCHIVEDPARAMETERGROUPRESPONSE
DESCRIPTOR.message_types_by_name['EnableBackfillingRequest'] = _ENABLEBACKFILLINGREQUEST
DESCRIPTOR.message_types_by_name['DisableBackfillingRequest'] = _DISABLEBACKFILLINGREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SubscribeBackfillingRequest = _reflection.GeneratedProtocolMessageType('SubscribeBackfillingRequest', (_message.Message,), {
  'DESCRIPTOR' : _SUBSCRIBEBACKFILLINGREQUEST,
  '__module__' : 'yamcs.protobuf.archive.parameter_archive_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.SubscribeBackfillingRequest)
  })
_sym_db.RegisterMessage(SubscribeBackfillingRequest)

SubscribeBackfillingData = _reflection.GeneratedProtocolMessageType('SubscribeBackfillingData', (_message.Message,), {

  'BackfillFinishedInfo' : _reflection.GeneratedProtocolMessageType('BackfillFinishedInfo', (_message.Message,), {
    'DESCRIPTOR' : _SUBSCRIBEBACKFILLINGDATA_BACKFILLFINISHEDINFO,
    '__module__' : 'yamcs.protobuf.archive.parameter_archive_service_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.SubscribeBackfillingData.BackfillFinishedInfo)
    })
  ,
  'DESCRIPTOR' : _SUBSCRIBEBACKFILLINGDATA,
  '__module__' : 'yamcs.protobuf.archive.parameter_archive_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.SubscribeBackfillingData)
  })
_sym_db.RegisterMessage(SubscribeBackfillingData)
_sym_db.RegisterMessage(SubscribeBackfillingData.BackfillFinishedInfo)

RebuildRangeRequest = _reflection.GeneratedProtocolMessageType('RebuildRangeRequest', (_message.Message,), {
  'DESCRIPTOR' : _REBUILDRANGEREQUEST,
  '__module__' : 'yamcs.protobuf.archive.parameter_archive_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.RebuildRangeRequest)
  })
_sym_db.RegisterMessage(RebuildRangeRequest)

PurgeRequest = _reflection.GeneratedProtocolMessageType('PurgeRequest', (_message.Message,), {
  'DESCRIPTOR' : _PURGEREQUEST,
  '__module__' : 'yamcs.protobuf.archive.parameter_archive_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.PurgeRequest)
  })
_sym_db.RegisterMessage(PurgeRequest)

GetArchivedParametersInfoRequest = _reflection.GeneratedProtocolMessageType('GetArchivedParametersInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETARCHIVEDPARAMETERSINFOREQUEST,
  '__module__' : 'yamcs.protobuf.archive.parameter_archive_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.GetArchivedParametersInfoRequest)
  })
_sym_db.RegisterMessage(GetArchivedParametersInfoRequest)

GetArchivedParameterSegmentsRequest = _reflection.GeneratedProtocolMessageType('GetArchivedParameterSegmentsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETARCHIVEDPARAMETERSEGMENTSREQUEST,
  '__module__' : 'yamcs.protobuf.archive.parameter_archive_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.GetArchivedParameterSegmentsRequest)
  })
_sym_db.RegisterMessage(GetArchivedParameterSegmentsRequest)

ArchivedParameterInfo = _reflection.GeneratedProtocolMessageType('ArchivedParameterInfo', (_message.Message,), {
  'DESCRIPTOR' : _ARCHIVEDPARAMETERINFO,
  '__module__' : 'yamcs.protobuf.archive.parameter_archive_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.ArchivedParameterInfo)
  })
_sym_db.RegisterMessage(ArchivedParameterInfo)

ArchivedParametersInfoResponse = _reflection.GeneratedProtocolMessageType('ArchivedParametersInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _ARCHIVEDPARAMETERSINFORESPONSE,
  '__module__' : 'yamcs.protobuf.archive.parameter_archive_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.ArchivedParametersInfoResponse)
  })
_sym_db.RegisterMessage(ArchivedParametersInfoResponse)

ArchiveParameterSegmentInfo = _reflection.GeneratedProtocolMessageType('ArchiveParameterSegmentInfo', (_message.Message,), {
  'DESCRIPTOR' : _ARCHIVEPARAMETERSEGMENTINFO,
  '__module__' : 'yamcs.protobuf.archive.parameter_archive_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.ArchiveParameterSegmentInfo)
  })
_sym_db.RegisterMessage(ArchiveParameterSegmentInfo)

ArchivedParameterSegmentsResponse = _reflection.GeneratedProtocolMessageType('ArchivedParameterSegmentsResponse', (_message.Message,), {
  'DESCRIPTOR' : _ARCHIVEDPARAMETERSEGMENTSRESPONSE,
  '__module__' : 'yamcs.protobuf.archive.parameter_archive_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.ArchivedParameterSegmentsResponse)
  })
_sym_db.RegisterMessage(ArchivedParameterSegmentsResponse)

GetArchivedParameterGroupRequest = _reflection.GeneratedProtocolMessageType('GetArchivedParameterGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETARCHIVEDPARAMETERGROUPREQUEST,
  '__module__' : 'yamcs.protobuf.archive.parameter_archive_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.GetArchivedParameterGroupRequest)
  })
_sym_db.RegisterMessage(GetArchivedParameterGroupRequest)

ArchivedParameterGroupResponse = _reflection.GeneratedProtocolMessageType('ArchivedParameterGroupResponse', (_message.Message,), {
  'DESCRIPTOR' : _ARCHIVEDPARAMETERGROUPRESPONSE,
  '__module__' : 'yamcs.protobuf.archive.parameter_archive_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.ArchivedParameterGroupResponse)
  })
_sym_db.RegisterMessage(ArchivedParameterGroupResponse)

EnableBackfillingRequest = _reflection.GeneratedProtocolMessageType('EnableBackfillingRequest', (_message.Message,), {
  'DESCRIPTOR' : _ENABLEBACKFILLINGREQUEST,
  '__module__' : 'yamcs.protobuf.archive.parameter_archive_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.EnableBackfillingRequest)
  })
_sym_db.RegisterMessage(EnableBackfillingRequest)

DisableBackfillingRequest = _reflection.GeneratedProtocolMessageType('DisableBackfillingRequest', (_message.Message,), {
  'DESCRIPTOR' : _DISABLEBACKFILLINGREQUEST,
  '__module__' : 'yamcs.protobuf.archive.parameter_archive_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.DisableBackfillingRequest)
  })
_sym_db.RegisterMessage(DisableBackfillingRequest)


DESCRIPTOR._options = None

_PARAMETERARCHIVEAPI = _descriptor.ServiceDescriptor(
  name='ParameterArchiveApi',
  full_name='yamcs.protobuf.archive.ParameterArchiveApi',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\320\200\001\001',
  serialized_start=1808,
  serialized_end=3384,
  methods=[
  _descriptor.MethodDescriptor(
    name='RebuildRange',
    full_name='yamcs.protobuf.archive.ParameterArchiveApi.RebuildRange',
    index=0,
    containing_service=None,
    input_type=_REBUILDRANGEREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\212\222\0037\0320/api/archive/{instance}/parameterArchive:rebuild:\001*H\001',
  ),
  _descriptor.MethodDescriptor(
    name='GetArchivedParametersInfo',
    full_name='yamcs.protobuf.archive.ParameterArchiveApi.GetArchivedParametersInfo',
    index=1,
    containing_service=None,
    input_type=_GETARCHIVEDPARAMETERSINFOREQUEST,
    output_type=_ARCHIVEDPARAMETERSINFORESPONSE,
    serialized_options=b'\212\222\003f\n&/api/parameter-archive/{instance}/pidsZ<\n8/api/archive/{instance}/parameterArchive/info/parameters0\001',
  ),
  _descriptor.MethodDescriptor(
    name='GetArchivedParameterSegments',
    full_name='yamcs.protobuf.archive.ParameterArchiveApi.GetArchivedParameterSegments',
    index=2,
    containing_service=None,
    input_type=_GETARCHIVEDPARAMETERSEGMENTSREQUEST,
    output_type=_ARCHIVEDPARAMETERSEGMENTSRESPONSE,
    serialized_options=b'\212\222\003y\n5/api/parameter-archive/{instance}/pids/{pid}/segmentsZ@\n</api/archive/{instance}/parameterArchive/info/segments/{pid}0\001',
  ),
  _descriptor.MethodDescriptor(
    name='GetArchivedParameterGroup',
    full_name='yamcs.protobuf.archive.ParameterArchiveApi.GetArchivedParameterGroup',
    index=3,
    containing_service=None,
    input_type=_GETARCHIVEDPARAMETERGROUPREQUEST,
    output_type=_ARCHIVEDPARAMETERGROUPRESPONSE,
    serialized_options=b'\212\222\003n\n,/api/parameter-archive/{instance}/gids/{gid}Z>\n:/api/archive/{instance}/parameterArchive/info/groups/{gid}0\001',
  ),
  _descriptor.MethodDescriptor(
    name='Purge',
    full_name='yamcs.protobuf.archive.ParameterArchiveApi.Purge',
    index=4,
    containing_service=None,
    input_type=_PURGEREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\212\222\0033\032./api/archive/{instance}/parameterArchive:purge:\001*',
  ),
  _descriptor.MethodDescriptor(
    name='DisableBackfilling',
    full_name='yamcs.protobuf.archive.ParameterArchiveApi.DisableBackfilling',
    index=5,
    containing_service=None,
    input_type=_DISABLEBACKFILLINGREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\212\222\003@\032;/api/archive/{instance}/parameterArchive:disableBackfilling:\001*',
  ),
  _descriptor.MethodDescriptor(
    name='EnableBackfilling',
    full_name='yamcs.protobuf.archive.ParameterArchiveApi.EnableBackfilling',
    index=6,
    containing_service=None,
    input_type=_ENABLEBACKFILLINGREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\212\222\003?\032:/api/archive/{instance}/parameterArchive:enableBackfilling:\001*',
  ),
  _descriptor.MethodDescriptor(
    name='SubscribeBackfilling',
    full_name='yamcs.protobuf.archive.ParameterArchiveApi.SubscribeBackfilling',
    index=7,
    containing_service=None,
    input_type=_SUBSCRIBEBACKFILLINGREQUEST,
    output_type=_SUBSCRIBEBACKFILLINGDATA,
    serialized_options=b'\332\222\003\r\n\013backfilling',
  ),
])
_sym_db.RegisterServiceDescriptor(_PARAMETERARCHIVEAPI)

DESCRIPTOR.services_by_name['ParameterArchiveApi'] = _PARAMETERARCHIVEAPI

# @@protoc_insertion_point(module_scope)
