# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yamcs/api/annotations.proto

from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yamcs/api/annotations.proto',
  package='yamcs.api',
  syntax='proto2',
  serialized_options=b'\n\rorg.yamcs.apiB\020AnnotationsProtoP\001',
  serialized_pb=b'\n\x1byamcs/api/annotations.proto\x12\tyamcs.api\x1a google/protobuf/descriptor.proto\"\x9b\x02\n\tHttpRoute\x12\r\n\x03get\x18\x01 \x01(\tH\x00\x12\r\n\x03put\x18\x02 \x01(\tH\x00\x12\x0e\n\x04post\x18\x03 \x01(\tH\x00\x12\x10\n\x06\x64\x65lete\x18\x04 \x01(\tH\x00\x12\x0f\n\x05patch\x18\x05 \x01(\tH\x00\x12\x12\n\ndeprecated\x18\x06 \x01(\x08\x12\x0c\n\x04\x62ody\x18\x07 \x01(\t\x12\x15\n\rmax_body_size\x18\x08 \x01(\x05\x12\x11\n\toffloaded\x18\t \x01(\x08\x12\x17\n\x0f\x66ield_mask_root\x18\n \x01(\t\x12\x31\n\x13\x61\x64\x64itional_bindings\x18\x0b \x03(\x0b\x32\x14.yamcs.api.HttpRoute\x12\x0b\n\x03log\x18\x0c \x01(\t\x12\r\n\x05label\x18\r \x01(\tB\t\n\x07pattern\"z\n\x0eWebSocketTopic\x12\r\n\x05topic\x18\x01 \x01(\t\x12\x12\n\ndeprecated\x18\x02 \x01(\x08\x12\x36\n\x13\x61\x64\x64itional_bindings\x18\x03 \x03(\x0b\x32\x19.yamcs.api.WebSocketTopic\x12\r\n\x05label\x18\x04 \x01(\t*;\n\rFieldBehavior\x12\x1e\n\x1a\x46IELD_BEHAVIOR_UNSPECIFIED\x10\x00\x12\n\n\x06SECRET\x10\x01:/\n\x05label\x12\x1f.google.protobuf.ServiceOptions\x18\x80\x10 \x01(\t:2\n\x08markdown\x12\x1f.google.protobuf.ServiceOptions\x18\x8a\x10 \x01(\x08:D\n\x05route\x12\x1e.google.protobuf.MethodOptions\x18\xa1\x32 \x01(\x0b\x32\x14.yamcs.api.HttpRoute:M\n\twebsocket\x12\x1e.google.protobuf.MethodOptions\x18\xab\x32 \x01(\x0b\x32\x19.yamcs.api.WebSocketTopic:P\n\x0e\x66ield_behavior\x12\x1d.google.protobuf.FieldOptions\x18\x85\x33 \x03(\x0e\x32\x18.yamcs.api.FieldBehaviorB#\n\rorg.yamcs.apiB\x10\x41nnotationsProtoP\x01'
  ,
  dependencies=[google_dot_protobuf_dot_descriptor__pb2.DESCRIPTOR,])

_FIELDBEHAVIOR = _descriptor.EnumDescriptor(
  name='FieldBehavior',
  full_name='yamcs.api.FieldBehavior',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='FIELD_BEHAVIOR_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SECRET', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=486,
  serialized_end=545,
)
_sym_db.RegisterEnumDescriptor(_FIELDBEHAVIOR)

FieldBehavior = enum_type_wrapper.EnumTypeWrapper(_FIELDBEHAVIOR)
FIELD_BEHAVIOR_UNSPECIFIED = 0
SECRET = 1

LABEL_FIELD_NUMBER = 2048
label = _descriptor.FieldDescriptor(
  name='label', full_name='yamcs.api.label', index=0,
  number=2048, type=9, cpp_type=9, label=1,
  has_default_value=False, default_value=b"".decode('utf-8'),
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR)
MARKDOWN_FIELD_NUMBER = 2058
markdown = _descriptor.FieldDescriptor(
  name='markdown', full_name='yamcs.api.markdown', index=1,
  number=2058, type=8, cpp_type=7, label=1,
  has_default_value=False, default_value=False,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR)
ROUTE_FIELD_NUMBER = 6433
route = _descriptor.FieldDescriptor(
  name='route', full_name='yamcs.api.route', index=2,
  number=6433, type=11, cpp_type=10, label=1,
  has_default_value=False, default_value=None,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR)
WEBSOCKET_FIELD_NUMBER = 6443
websocket = _descriptor.FieldDescriptor(
  name='websocket', full_name='yamcs.api.websocket', index=3,
  number=6443, type=11, cpp_type=10, label=1,
  has_default_value=False, default_value=None,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR)
FIELD_BEHAVIOR_FIELD_NUMBER = 6533
field_behavior = _descriptor.FieldDescriptor(
  name='field_behavior', full_name='yamcs.api.field_behavior', index=4,
  number=6533, type=14, cpp_type=8, label=3,
  has_default_value=False, default_value=[],
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR)


_HTTPROUTE = _descriptor.Descriptor(
  name='HttpRoute',
  full_name='yamcs.api.HttpRoute',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='get', full_name='yamcs.api.HttpRoute.get', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='put', full_name='yamcs.api.HttpRoute.put', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='post', full_name='yamcs.api.HttpRoute.post', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='delete', full_name='yamcs.api.HttpRoute.delete', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='patch', full_name='yamcs.api.HttpRoute.patch', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deprecated', full_name='yamcs.api.HttpRoute.deprecated', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='body', full_name='yamcs.api.HttpRoute.body', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_body_size', full_name='yamcs.api.HttpRoute.max_body_size', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='offloaded', full_name='yamcs.api.HttpRoute.offloaded', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='field_mask_root', full_name='yamcs.api.HttpRoute.field_mask_root', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='additional_bindings', full_name='yamcs.api.HttpRoute.additional_bindings', index=10,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='log', full_name='yamcs.api.HttpRoute.log', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='label', full_name='yamcs.api.HttpRoute.label', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='pattern', full_name='yamcs.api.HttpRoute.pattern',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=77,
  serialized_end=360,
)


_WEBSOCKETTOPIC = _descriptor.Descriptor(
  name='WebSocketTopic',
  full_name='yamcs.api.WebSocketTopic',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='topic', full_name='yamcs.api.WebSocketTopic.topic', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deprecated', full_name='yamcs.api.WebSocketTopic.deprecated', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='additional_bindings', full_name='yamcs.api.WebSocketTopic.additional_bindings', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='label', full_name='yamcs.api.WebSocketTopic.label', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=362,
  serialized_end=484,
)

_HTTPROUTE.fields_by_name['additional_bindings'].message_type = _HTTPROUTE
_HTTPROUTE.oneofs_by_name['pattern'].fields.append(
  _HTTPROUTE.fields_by_name['get'])
_HTTPROUTE.fields_by_name['get'].containing_oneof = _HTTPROUTE.oneofs_by_name['pattern']
_HTTPROUTE.oneofs_by_name['pattern'].fields.append(
  _HTTPROUTE.fields_by_name['put'])
_HTTPROUTE.fields_by_name['put'].containing_oneof = _HTTPROUTE.oneofs_by_name['pattern']
_HTTPROUTE.oneofs_by_name['pattern'].fields.append(
  _HTTPROUTE.fields_by_name['post'])
_HTTPROUTE.fields_by_name['post'].containing_oneof = _HTTPROUTE.oneofs_by_name['pattern']
_HTTPROUTE.oneofs_by_name['pattern'].fields.append(
  _HTTPROUTE.fields_by_name['delete'])
_HTTPROUTE.fields_by_name['delete'].containing_oneof = _HTTPROUTE.oneofs_by_name['pattern']
_HTTPROUTE.oneofs_by_name['pattern'].fields.append(
  _HTTPROUTE.fields_by_name['patch'])
_HTTPROUTE.fields_by_name['patch'].containing_oneof = _HTTPROUTE.oneofs_by_name['pattern']
_WEBSOCKETTOPIC.fields_by_name['additional_bindings'].message_type = _WEBSOCKETTOPIC
DESCRIPTOR.message_types_by_name['HttpRoute'] = _HTTPROUTE
DESCRIPTOR.message_types_by_name['WebSocketTopic'] = _WEBSOCKETTOPIC
DESCRIPTOR.enum_types_by_name['FieldBehavior'] = _FIELDBEHAVIOR
DESCRIPTOR.extensions_by_name['label'] = label
DESCRIPTOR.extensions_by_name['markdown'] = markdown
DESCRIPTOR.extensions_by_name['route'] = route
DESCRIPTOR.extensions_by_name['websocket'] = websocket
DESCRIPTOR.extensions_by_name['field_behavior'] = field_behavior
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

HttpRoute = _reflection.GeneratedProtocolMessageType('HttpRoute', (_message.Message,), {
  'DESCRIPTOR' : _HTTPROUTE,
  '__module__' : 'yamcs.api.annotations_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.api.HttpRoute)
  })
_sym_db.RegisterMessage(HttpRoute)

WebSocketTopic = _reflection.GeneratedProtocolMessageType('WebSocketTopic', (_message.Message,), {
  'DESCRIPTOR' : _WEBSOCKETTOPIC,
  '__module__' : 'yamcs.api.annotations_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.api.WebSocketTopic)
  })
_sym_db.RegisterMessage(WebSocketTopic)

google_dot_protobuf_dot_descriptor__pb2.ServiceOptions.RegisterExtension(label)
google_dot_protobuf_dot_descriptor__pb2.ServiceOptions.RegisterExtension(markdown)
route.message_type = _HTTPROUTE
google_dot_protobuf_dot_descriptor__pb2.MethodOptions.RegisterExtension(route)
websocket.message_type = _WEBSOCKETTOPIC
google_dot_protobuf_dot_descriptor__pb2.MethodOptions.RegisterExtension(websocket)
field_behavior.enum_type = _FIELDBEHAVIOR
google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(field_behavior)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
