import warnings

warnings.warn(
    "The module 'yamcs.core.helpers' is deprecated. "
    "Import classes from 'yamcs.client' instead.",
    DeprecationWarning,
    stacklevel=2,
)

from yamcs.client.core.helpers import (  # noqa
    FixedDelay,
    ProtoList,
    adapt_name_for_rest,
    delimit_protobuf,
    do_get,
    do_post,
    do_request,
    parse_server_time,
    parse_server_timestring,
    parse_value,
    split_protobuf_stream,
    to_argument_value,
    to_isostring,
    to_named_object_id,
    to_named_object_ids,
    to_server_time,
)
