# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yamcs/protobuf/replication/replication.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from yamcs.api import annotations_pb2 as yamcs_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yamcs/protobuf/replication/replication.proto',
  package='yamcs.protobuf.replication',
  syntax='proto2',
  serialized_options=b'\n\022org.yamcs.protobufB\020ReplicationProtoP\001',
  serialized_pb=b'\n,yamcs/protobuf/replication/replication.proto\x12\x1ayamcs.protobuf.replication\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1byamcs/api/annotations.proto\"\x97\x01\n\x0fReplicationInfo\x12\x42\n\x07masters\x18\x01 \x03(\x0b\x32\x31.yamcs.protobuf.replication.ReplicationMasterInfo\x12@\n\x06slaves\x18\x02 \x03(\x0b\x32\x30.yamcs.protobuf.replication.ReplicationSlaveInfo\"\xa6\x01\n\x15ReplicationMasterInfo\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x0f\n\x07streams\x18\x02 \x03(\t\x12\x14\n\x0clocalAddress\x18\x03 \x01(\t\x12\x15\n\rremoteAddress\x18\x04 \x01(\t\x12\x0c\n\x04push\x18\x05 \x01(\x08\x12\x0e\n\x06pushTo\x18\x06 \x01(\t\x12\x0f\n\x07localTx\x18\x07 \x01(\x03\x12\x0e\n\x06nextTx\x18\x08 \x01(\x03\"\x92\x01\n\x14ReplicationSlaveInfo\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x0f\n\x07streams\x18\x02 \x03(\t\x12\x14\n\x0clocalAddress\x18\x03 \x01(\t\x12\x15\n\rremoteAddress\x18\x04 \x01(\t\x12\x0c\n\x04push\x18\x05 \x01(\x08\x12\x10\n\x08pullFrom\x18\x06 \x01(\t\x12\n\n\x02tx\x18\x07 \x01(\x03\x32\x84\x02\n\x0eReplicationApi\x12q\n\x12GetReplicationInfo\x12\x16.google.protobuf.Empty\x1a+.yamcs.protobuf.replication.ReplicationInfo\"\x16\x8a\x92\x03\x12\n\x10/api/replication\x12y\n\x18SubscribeReplicationInfo\x12\x16.google.protobuf.Empty\x1a+.yamcs.protobuf.replication.ReplicationInfo\"\x16\xda\x92\x03\x12\n\x10replication-info0\x01\x1a\x04\xd0\x80\x01\x01\x42(\n\x12org.yamcs.protobufB\x10ReplicationProtoP\x01'
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,yamcs_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_REPLICATIONINFO = _descriptor.Descriptor(
  name='ReplicationInfo',
  full_name='yamcs.protobuf.replication.ReplicationInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='masters', full_name='yamcs.protobuf.replication.ReplicationInfo.masters', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='slaves', full_name='yamcs.protobuf.replication.ReplicationInfo.slaves', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=135,
  serialized_end=286,
)


_REPLICATIONMASTERINFO = _descriptor.Descriptor(
  name='ReplicationMasterInfo',
  full_name='yamcs.protobuf.replication.ReplicationMasterInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.replication.ReplicationMasterInfo.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='streams', full_name='yamcs.protobuf.replication.ReplicationMasterInfo.streams', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='localAddress', full_name='yamcs.protobuf.replication.ReplicationMasterInfo.localAddress', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remoteAddress', full_name='yamcs.protobuf.replication.ReplicationMasterInfo.remoteAddress', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='push', full_name='yamcs.protobuf.replication.ReplicationMasterInfo.push', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pushTo', full_name='yamcs.protobuf.replication.ReplicationMasterInfo.pushTo', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='localTx', full_name='yamcs.protobuf.replication.ReplicationMasterInfo.localTx', index=6,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nextTx', full_name='yamcs.protobuf.replication.ReplicationMasterInfo.nextTx', index=7,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=289,
  serialized_end=455,
)


_REPLICATIONSLAVEINFO = _descriptor.Descriptor(
  name='ReplicationSlaveInfo',
  full_name='yamcs.protobuf.replication.ReplicationSlaveInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.replication.ReplicationSlaveInfo.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='streams', full_name='yamcs.protobuf.replication.ReplicationSlaveInfo.streams', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='localAddress', full_name='yamcs.protobuf.replication.ReplicationSlaveInfo.localAddress', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remoteAddress', full_name='yamcs.protobuf.replication.ReplicationSlaveInfo.remoteAddress', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='push', full_name='yamcs.protobuf.replication.ReplicationSlaveInfo.push', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pullFrom', full_name='yamcs.protobuf.replication.ReplicationSlaveInfo.pullFrom', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tx', full_name='yamcs.protobuf.replication.ReplicationSlaveInfo.tx', index=6,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=458,
  serialized_end=604,
)

_REPLICATIONINFO.fields_by_name['masters'].message_type = _REPLICATIONMASTERINFO
_REPLICATIONINFO.fields_by_name['slaves'].message_type = _REPLICATIONSLAVEINFO
DESCRIPTOR.message_types_by_name['ReplicationInfo'] = _REPLICATIONINFO
DESCRIPTOR.message_types_by_name['ReplicationMasterInfo'] = _REPLICATIONMASTERINFO
DESCRIPTOR.message_types_by_name['ReplicationSlaveInfo'] = _REPLICATIONSLAVEINFO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ReplicationInfo = _reflection.GeneratedProtocolMessageType('ReplicationInfo', (_message.Message,), {
  'DESCRIPTOR' : _REPLICATIONINFO,
  '__module__' : 'yamcs.protobuf.replication.replication_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.replication.ReplicationInfo)
  })
_sym_db.RegisterMessage(ReplicationInfo)

ReplicationMasterInfo = _reflection.GeneratedProtocolMessageType('ReplicationMasterInfo', (_message.Message,), {
  'DESCRIPTOR' : _REPLICATIONMASTERINFO,
  '__module__' : 'yamcs.protobuf.replication.replication_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.replication.ReplicationMasterInfo)
  })
_sym_db.RegisterMessage(ReplicationMasterInfo)

ReplicationSlaveInfo = _reflection.GeneratedProtocolMessageType('ReplicationSlaveInfo', (_message.Message,), {
  'DESCRIPTOR' : _REPLICATIONSLAVEINFO,
  '__module__' : 'yamcs.protobuf.replication.replication_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.replication.ReplicationSlaveInfo)
  })
_sym_db.RegisterMessage(ReplicationSlaveInfo)


DESCRIPTOR._options = None

_REPLICATIONAPI = _descriptor.ServiceDescriptor(
  name='ReplicationApi',
  full_name='yamcs.protobuf.replication.ReplicationApi',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\320\200\001\001',
  serialized_start=607,
  serialized_end=867,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetReplicationInfo',
    full_name='yamcs.protobuf.replication.ReplicationApi.GetReplicationInfo',
    index=0,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_REPLICATIONINFO,
    serialized_options=b'\212\222\003\022\n\020/api/replication',
  ),
  _descriptor.MethodDescriptor(
    name='SubscribeReplicationInfo',
    full_name='yamcs.protobuf.replication.ReplicationApi.SubscribeReplicationInfo',
    index=1,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_REPLICATIONINFO,
    serialized_options=b'\332\222\003\022\n\020replication-info',
  ),
])
_sym_db.RegisterServiceDescriptor(_REPLICATIONAPI)

DESCRIPTOR.services_by_name['ReplicationApi'] = _REPLICATIONAPI

# @@protoc_insertion_point(module_scope)
