# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yamcs/protobuf/database/database_service.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from yamcs.api import annotations_pb2 as yamcs_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yamcs/protobuf/database/database_service.proto',
  package='yamcs.protobuf.archive',
  syntax='proto2',
  serialized_options=b'\n\022org.yamcs.protobufB\016DbServiceProtoP\001',
  serialized_pb=b'\n.yamcs/protobuf/database/database_service.proto\x12\x16yamcs.protobuf.archive\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1byamcs/api/annotations.proto\"P\n\x15ListDatabasesResponse\x12\x37\n\tdatabases\x18\x01 \x03(\x0b\x32$.yamcs.protobuf.archive.DatabaseInfo\"\"\n\x12GetDatabaseRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"_\n\x0c\x44\x61tabaseInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x12\n\ntablespace\x18\x03 \x01(\t\x12\x0e\n\x06tables\x18\x04 \x03(\t\x12\x0f\n\x07streams\x18\x05 \x03(\t2\xff\x01\n\x0b\x44\x61tabaseApi\x12l\n\rListDatabases\x12\x16.google.protobuf.Empty\x1a-.yamcs.protobuf.archive.ListDatabasesResponse\"\x14\x8a\x92\x03\x10\n\x0e/api/databases\x12|\n\x0bGetDatabase\x12*.yamcs.protobuf.archive.GetDatabaseRequest\x1a$.yamcs.protobuf.archive.DatabaseInfo\"\x1b\x8a\x92\x03\x17\n\x15/api/databases/{name}\x1a\x04\xd0\x80\x01\x01\x42&\n\x12org.yamcs.protobufB\x0e\x44\x62ServiceProtoP\x01'
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,yamcs_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_LISTDATABASESRESPONSE = _descriptor.Descriptor(
  name='ListDatabasesResponse',
  full_name='yamcs.protobuf.archive.ListDatabasesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='databases', full_name='yamcs.protobuf.archive.ListDatabasesResponse.databases', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=132,
  serialized_end=212,
)


_GETDATABASEREQUEST = _descriptor.Descriptor(
  name='GetDatabaseRequest',
  full_name='yamcs.protobuf.archive.GetDatabaseRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.archive.GetDatabaseRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=214,
  serialized_end=248,
)


_DATABASEINFO = _descriptor.Descriptor(
  name='DatabaseInfo',
  full_name='yamcs.protobuf.archive.DatabaseInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.archive.DatabaseInfo.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='path', full_name='yamcs.protobuf.archive.DatabaseInfo.path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tablespace', full_name='yamcs.protobuf.archive.DatabaseInfo.tablespace', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tables', full_name='yamcs.protobuf.archive.DatabaseInfo.tables', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='streams', full_name='yamcs.protobuf.archive.DatabaseInfo.streams', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=250,
  serialized_end=345,
)

_LISTDATABASESRESPONSE.fields_by_name['databases'].message_type = _DATABASEINFO
DESCRIPTOR.message_types_by_name['ListDatabasesResponse'] = _LISTDATABASESRESPONSE
DESCRIPTOR.message_types_by_name['GetDatabaseRequest'] = _GETDATABASEREQUEST
DESCRIPTOR.message_types_by_name['DatabaseInfo'] = _DATABASEINFO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListDatabasesResponse = _reflection.GeneratedProtocolMessageType('ListDatabasesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATABASESRESPONSE,
  '__module__' : 'yamcs.protobuf.database.database_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.ListDatabasesResponse)
  })
_sym_db.RegisterMessage(ListDatabasesResponse)

GetDatabaseRequest = _reflection.GeneratedProtocolMessageType('GetDatabaseRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDATABASEREQUEST,
  '__module__' : 'yamcs.protobuf.database.database_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.GetDatabaseRequest)
  })
_sym_db.RegisterMessage(GetDatabaseRequest)

DatabaseInfo = _reflection.GeneratedProtocolMessageType('DatabaseInfo', (_message.Message,), {
  'DESCRIPTOR' : _DATABASEINFO,
  '__module__' : 'yamcs.protobuf.database.database_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.DatabaseInfo)
  })
_sym_db.RegisterMessage(DatabaseInfo)


DESCRIPTOR._options = None

_DATABASEAPI = _descriptor.ServiceDescriptor(
  name='DatabaseApi',
  full_name='yamcs.protobuf.archive.DatabaseApi',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\320\200\001\001',
  serialized_start=348,
  serialized_end=603,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListDatabases',
    full_name='yamcs.protobuf.archive.DatabaseApi.ListDatabases',
    index=0,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_LISTDATABASESRESPONSE,
    serialized_options=b'\212\222\003\020\n\016/api/databases',
  ),
  _descriptor.MethodDescriptor(
    name='GetDatabase',
    full_name='yamcs.protobuf.archive.DatabaseApi.GetDatabase',
    index=1,
    containing_service=None,
    input_type=_GETDATABASEREQUEST,
    output_type=_DATABASEINFO,
    serialized_options=b'\212\222\003\027\n\025/api/databases/{name}',
  ),
])
_sym_db.RegisterServiceDescriptor(_DATABASEAPI)

DESCRIPTOR.services_by_name['DatabaseApi'] = _DATABASEAPI

# @@protoc_insertion_point(module_scope)
